@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,7 +38,7 @@ static gboolean on_dialog_keypressed (GtkWidget *dialog, GdkEventKey *event, gpo
 {
     if (event->keyval == GDK_Escape)
     {
-        gtk_widget_hide (dialog);
+        gtk_widget_destroy (dialog);
         return TRUE;
     }
 
@@ -117,7 +118,7 @@ static void init (GnomeCmdDialog *dialog)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_dialog_get_type (void)
+GtkType gnome_cmd_dialog_get_type ()
 {
     static GtkType dlg_type = 0;
 
