@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -143,10 +144,10 @@ setup_widget (GnomeCmdStringDialog *string_dialog, gint rows)
 
     gnome_cmd_dialog_add_button (
         GNOME_CMD_DIALOG (dialog),
-        GNOME_STOCK_BUTTON_CANCEL, GTK_SIGNAL_FUNC (on_cancel), string_dialog);
+        GTK_STOCK_CANCEL, GTK_SIGNAL_FUNC (on_cancel), string_dialog);
     btn = gnome_cmd_dialog_add_button (
         GNOME_CMD_DIALOG (dialog),
-        GNOME_STOCK_BUTTON_OK, GTK_SIGNAL_FUNC (on_ok), string_dialog);
+        GTK_STOCK_OK, GTK_SIGNAL_FUNC (on_ok), string_dialog);
 
     gtk_widget_grab_focus (string_dialog->entries[0]);
     gtk_widget_grab_default (btn);
@@ -158,7 +159,7 @@ setup_widget (GnomeCmdStringDialog *string_dialog, gint rows)
  ***********************************/
 
 GtkType
-gnome_cmd_string_dialog_get_type         (void)
+gnome_cmd_string_dialog_get_type ()
 {
     static GtkType dlg_type = 0;
 
