@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -57,11 +58,9 @@ struct _CvsPluginClass
 };
 
 
-GtkType
-cvs_plugin_get_type (void);
+GtkType cvs_plugin_get_type ();
 
-GnomeCmdPlugin *
-cvs_plugin_new (void);
+GnomeCmdPlugin *cvs_plugin_new ();
 
 G_END_DECLS
 
