@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -48,10 +49,10 @@ struct _TestPluginClass
 
 
 GtkType
-test_plugin_get_type (void);
+test_plugin_get_type ();
 
 GnomeCmdPlugin *
-test_plugin_new (void);
+test_plugin_new ();
 
 G_END_DECLS
 
