@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +22,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <errno.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-chmod-dialog.h"
 #include "gnome-cmd-chmod-component.h"
@@ -44,10 +46,10 @@ static gchar *recurse_opts[CHMOD_MAX] = {
     N_("Directories only")
 };
 
-struct _GnomeCmdChmodDialogPrivate
+struct GnomeCmdChmodDialogPrivate
 {
     GList *files;
-    GnomeCmdFile *finfo;
+    GnomeCmdFile *f;
     GnomeVFSFilePermissions perms;
 
     GtkWidget *chmod_component;
@@ -59,26 +61,25 @@ struct _GnomeCmdChmodDialogPrivate
 static GnomeCmdDialogClass *parent_class = NULL;
 
 
-static void do_chmod (GnomeCmdFile *in_finfo, GnomeVFSFilePermissions perm,
-                      gboolean recursive, ChmodRecursiveMode mode)
+static void do_chmod (GnomeCmdFile *in, GnomeVFSFilePermissions perm, gboolean recursive, ChmodRecursiveMode mode)
 {
-    g_return_if_fail (in_finfo != NULL);
-    g_return_if_fail (in_finfo->info != NULL);
+    g_return_if_fail (in != NULL);
+    g_return_if_fail (in->info != NULL);
 
-    if (!(recursive && mode == CHMOD_DIRS_ONLY && in_finfo->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY))
+    if (!(recursive && mode == CHMOD_DIRS_ONLY && in->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY))
     {
-        GnomeVFSResult ret = gnome_cmd_file_chmod (in_finfo, perm);
+        GnomeVFSResult ret = gnome_cmd_file_chmod (in, perm);
 
         if (ret != GNOME_VFS_OK)
-            gnome_cmd_show_message (NULL, gnome_cmd_file_get_name (in_finfo), gnome_vfs_result_to_string (ret));
+            gnome_cmd_show_message (NULL, gnome_cmd_file_get_name (in), gnome_vfs_result_to_string (ret));
         else
             if (!recursive)
                 return;
     }
 
-    if (in_finfo->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+    if (in->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
     {
-        GnomeCmdDir *dir = GNOME_CMD_DIR (in_finfo);
+        GnomeCmdDir *dir = GNOME_CMD_DIR (in);
         GList *files;
 
         gnome_cmd_dir_ref (dir);
@@ -87,12 +88,12 @@ static void do_chmod (GnomeCmdFile *in_finfo, GnomeVFSFilePermissions perm,
 
         for (GList *tmp = files; tmp; tmp = tmp->next)
         {
-            GnomeCmdFile *finfo = (GnomeCmdFile *) tmp->data;
-            if (strcmp (finfo->info->name, ".") != 0
-                && strcmp (finfo->info->name, "..") != 0
-                && !GNOME_VFS_FILE_INFO_SYMLINK(finfo->info))
+            GnomeCmdFile *f = (GnomeCmdFile *) tmp->data;
+            if (strcmp (f->info->name, ".") != 0
+                && strcmp (f->info->name, "..") != 0
+                && !GNOME_VFS_FILE_INFO_SYMLINK(f->info))
             {
-                do_chmod (finfo, perm, TRUE, mode);
+                do_chmod (f, perm, TRUE, mode);
             }
         }
         gnome_cmd_dir_unref (dir);
@@ -104,13 +105,13 @@ inline void do_chmod_files (GnomeCmdChmodDialog *dialog)
 {
     for (GList *tmp = dialog->priv->files; tmp; tmp = tmp->next)
     {
-        GnomeCmdFile *finfo = (GnomeCmdFile *) tmp->data;
+        GnomeCmdFile *f = (GnomeCmdFile *) tmp->data;
         gboolean recursive = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->recurse_check));
         const gchar *mode_text = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (dialog->priv->recurse_combo)->entry));
         ChmodRecursiveMode mode = strcmp (mode_text, recurse_opts[CHMOD_ALL_FILES]) == 0 ? CHMOD_ALL_FILES :
                                                                                            CHMOD_DIRS_ONLY;
 
-        do_chmod (finfo, dialog->priv->perms, recursive, mode);
+        do_chmod (f, dialog->priv->perms, recursive, mode);
         view_refresh (NULL, NULL);
     }
 }
@@ -219,14 +220,14 @@ static void init (GnomeCmdChmodDialog *dialog)
     gtk_widget_set_sensitive (dialog->priv->recurse_combo, FALSE);
 
 
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_CANCEL,
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CANCEL,
                                  GTK_SIGNAL_FUNC (on_cancel), dialog);
-    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_OK,
+    gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK,
                                  GTK_SIGNAL_FUNC (on_ok), dialog);
 
     gtk_signal_connect (GTK_OBJECT (dialog->priv->recurse_check), "toggled",
                         GTK_SIGNAL_FUNC (on_toggle_recurse), chmod_dialog);
-    gtk_signal_connect (GTK_OBJECT (dialog->priv->chmod_component), "perms_changed",
+    gtk_signal_connect (GTK_OBJECT (dialog->priv->chmod_component), "perms-changed",
                         GTK_SIGNAL_FUNC (on_perms_changed), chmod_dialog);
 }
 
@@ -242,10 +243,10 @@ GtkWidget *gnome_cmd_chmod_dialog_new (GList *files)
     GnomeCmdChmodDialog *dialog = (GnomeCmdChmodDialog *) gtk_type_new (gnome_cmd_chmod_dialog_get_type ());
     dialog->priv->files = gnome_cmd_file_list_copy (files);
 
-    dialog->priv->finfo = (GnomeCmdFile *) dialog->priv->files->data;
-    g_return_val_if_fail (dialog->priv->finfo != NULL, NULL);
+    dialog->priv->f = (GnomeCmdFile *) dialog->priv->files->data;
+    g_return_val_if_fail (dialog->priv->f != NULL, NULL);
 
-    dialog->priv->perms = dialog->priv->finfo->info->permissions;
+    dialog->priv->perms = dialog->priv->f->info->permissions;
 
     show_perms (dialog);
 
@@ -260,7 +261,7 @@ GtkWidget *gnome_cmd_chmod_dialog_new (GList *files)
 }
 
 
-GtkType gnome_cmd_chmod_dialog_get_type (void)
+GtkType gnome_cmd_chmod_dialog_get_type ()
 {
     static GtkType dlg_type = 0;
 
