@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-clist.h"
 #include "gnome-cmd-data.h"
@@ -29,7 +31,7 @@ using namespace std;
 static GtkCListClass *parent_class = NULL;
 
 
-struct _GnomeCmdCListPrivate
+struct GnomeCmdCListPrivate
 {
 };
 
@@ -341,7 +343,7 @@ static void draw_row (GtkCList *clist, GdkRectangle *area, gint row, GtkCListRow
                                     intersect_rectangle.height);
         }
 
-        if (!gdk_rectangle_intersect (area, &row_rectangle,&intersect_rectangle))
+        if (!gdk_rectangle_intersect (area, &row_rectangle, &intersect_rectangle))
             return;
 
     }
@@ -525,7 +527,7 @@ static void draw_row (GtkCList *clist, GdkRectangle *area, gint row, GtkCListRow
  ****/
 static void on_hadj_value_changed (GtkAdjustment *adjustment, GnomeCmdCList *clist)
 {
-    gtk_widget_draw(GTK_WIDGET(clist),NULL);
+    gtk_widget_draw(GTK_WIDGET(clist), NULL);
 }
 
 
@@ -590,7 +592,7 @@ static void init (GnomeCmdCList *clist)
     
     GTK_CLIST (clist)->focus_row = 0;
 
-    gtk_signal_connect_after (GTK_OBJECT (clist), "scroll_vertical", GTK_SIGNAL_FUNC (on_scroll_vertical), NULL);
+    gtk_signal_connect_after (GTK_OBJECT (clist), "scroll-vertical", GTK_SIGNAL_FUNC (on_scroll_vertical), NULL);
     gtk_signal_connect (GTK_OBJECT (clist), "realize", GTK_SIGNAL_FUNC (on_realize), NULL);
 }
 
@@ -599,7 +601,7 @@ static void init (GnomeCmdCList *clist)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_clist_get_type         (void)
+GtkType gnome_cmd_clist_get_type ()
 {
     static GtkType type = 0;
 
