@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,19 +34,18 @@
     GTK_CHECK_TYPE (obj, gnome_cmd_con_list_get_type ())
 
 
-typedef struct _GnomeCmdConList GnomeCmdConList;
-typedef struct _GnomeCmdConListClass GnomeCmdConListClass;
-typedef struct _GnomeCmdConListPrivate GnomeCmdConListPrivate;
+struct GnomeCmdConListPrivate;
 
 
-struct _GnomeCmdConList
+struct GnomeCmdConList
 {
     GtkObject parent;
 
     GnomeCmdConListPrivate *priv;
 };
 
-struct _GnomeCmdConListClass
+
+struct GnomeCmdConListClass
 {
     GtkObjectClass parent_class;
 
@@ -57,11 +57,11 @@ struct _GnomeCmdConListClass
 };
 
 
-GtkType gnome_cmd_con_list_get_type (void);
+GtkType gnome_cmd_con_list_get_type ();
 
-GnomeCmdConList *gnome_cmd_con_list_new (void);
+GnomeCmdConList *gnome_cmd_con_list_new ();
 
-inline GnomeCmdConList *gnome_cmd_con_list_get (void)
+inline GnomeCmdConList *gnome_cmd_con_list_get ()
 {
     return (GnomeCmdConList *) gnome_cmd_data_get_con_list ();
 }
@@ -96,12 +96,12 @@ inline gboolean gnome_cmd_con_list_has_alias (GnomeCmdConList *list, const gchar
 GnomeCmdCon *gnome_cmd_con_list_get_home (GnomeCmdConList *list);
 GnomeCmdCon *gnome_cmd_con_list_get_smb (GnomeCmdConList *con_list);
 
-inline GnomeCmdCon *get_home_con (void)
+inline GnomeCmdCon *get_home_con ()
 {
     return gnome_cmd_con_list_get_home (gnome_cmd_con_list_get ());
 }
 
-inline GnomeCmdCon *get_smb_con (void)
+inline GnomeCmdCon *get_smb_con ()
 {
     return gnome_cmd_con_list_get_smb (gnome_cmd_con_list_get ());
 }
