@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-file-popmenu.h"
 #include "gnome-cmd-file.h"
@@ -48,7 +50,8 @@ typedef struct
 
 static GtkMenuClass *parent_class = NULL;
 
-struct _GnomeCmdFilePopmenuPrivate
+
+struct GnomeCmdFilePopmenuPrivate
 {
     GList *data_list;
 };
@@ -88,8 +91,8 @@ static void cb_exec_default (GtkMenuItem *menu_item, GList *files)
 
     for (; files; files = files->next)
     {
-        GnomeCmdFile *finfo = (GnomeCmdFile *) files->data;
-        GnomeVFSMimeApplication *vfs_app = gnome_cmd_app_get_default_application (finfo);
+        GnomeCmdFile *f = (GnomeCmdFile *) files->data;
+        GnomeVFSMimeApplication *vfs_app = gnome_cmd_app_get_default_application (f);
 
         if (vfs_app)
         {
@@ -104,10 +107,10 @@ static void cb_exec_default (GtkMenuItem *menu_item, GList *files)
             }
 
             gnome_vfs_mime_application_free (vfs_app);
-            data->files = g_list_append (data->files, finfo);
+            data->files = g_list_append (data->files, f);
         }
         else
-            gnome_cmd_show_message (NULL, finfo->info->name, _("Couldn't retrieve MIME type of the file."));
+            gnome_cmd_show_message (NULL, f->info->name, _("Couldn't retrieve MIME type of the file."));
     }
 
     g_hash_table_foreach (hash, (GHFunc) htcb_exec_with_app, NULL);
@@ -135,7 +138,7 @@ static gboolean on_open_with_other_ok (GnomeCmdStringDialog *string_dialog, cons
     }
 
     GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
-    GnomeCmdDir *dir = gnome_cmd_file_selector_get_directory (fs);
+    GnomeCmdDir *dir = fs->get_directory();
     gchar *dpath = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dir));
     run_command_indir (cmd.c_str(), dpath, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (term_check)));
     g_free (dpath);
@@ -157,7 +160,7 @@ static void on_open_with_other (GtkMenuItem *menu_item, GList *files)
     GtkWidget *term_check = create_check (dialog, _("Needs terminal"), "term_check");
 
     gtk_widget_ref (dialog);
-    gtk_object_set_data_full (GTK_OBJECT (menu_item), "new_textfile_dialog", dialog, (GtkDestroyNotify)gtk_widget_unref);
+    gtk_object_set_data_full (GTK_OBJECT (menu_item), "new_textfile_dialog", dialog, (GtkDestroyNotify) gtk_widget_unref);
 
     gnome_cmd_dialog_add_category (GNOME_CMD_DIALOG (dialog), term_check);
 
@@ -167,9 +170,9 @@ static void on_open_with_other (GtkMenuItem *menu_item, GList *files)
 
 static void on_execute (GtkMenuItem *menu_item, GList *files)
 {
-    GnomeCmdFile *finfo = GNOME_CMD_FILE (files->data);
+    GnomeCmdFile *f = GNOME_CMD_FILE (files->data);
 
-    gnome_cmd_file_execute (finfo);
+    gnome_cmd_file_execute (f);
 }
 
 
@@ -252,8 +255,8 @@ inline gboolean fav_app_matches_files (GnomeCmdApp *app, GList *files)
         case APP_TARGET_ALL_DIRS:
             for (; files; files = files->next)
             {
-                GnomeCmdFile *finfo = (GnomeCmdFile *) files->data;
-                if (finfo->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
+                GnomeCmdFile *f = (GnomeCmdFile *) files->data;
+                if (f->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
                     return FALSE;
             }
             return TRUE;
@@ -261,8 +264,8 @@ inline gboolean fav_app_matches_files (GnomeCmdApp *app, GList *files)
         case APP_TARGET_ALL_FILES:
             for (; files; files = files->next)
             {
-                GnomeCmdFile *finfo = (GnomeCmdFile *) files->data;
-                if (finfo->info->type != GNOME_VFS_FILE_TYPE_REGULAR)
+                GnomeCmdFile *f = (GnomeCmdFile *) files->data;
+                if (f->info->type != GNOME_VFS_FILE_TYPE_REGULAR)
                     return FALSE;
             }
             return TRUE;
@@ -270,9 +273,9 @@ inline gboolean fav_app_matches_files (GnomeCmdApp *app, GList *files)
         case APP_TARGET_ALL_DIRS_AND_FILES:
             for (; files; files = files->next)
             {
-                GnomeCmdFile *finfo = (GnomeCmdFile *) files->data;
-                if (finfo->info->type != GNOME_VFS_FILE_TYPE_REGULAR
-                    && finfo->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
+                GnomeCmdFile *f = (GnomeCmdFile *) files->data;
+                if (f->info->type != GNOME_VFS_FILE_TYPE_REGULAR
+                    && f->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
                     return FALSE;
             }
             return TRUE;
@@ -287,8 +290,8 @@ inline gboolean fav_app_matches_files (GnomeCmdApp *app, GList *files)
                 gint fn_flags = FNM_NOESCAPE;
 #endif
 
-                GnomeCmdFile *finfo = (GnomeCmdFile *) files->data;
-                if (finfo->info->type != GNOME_VFS_FILE_TYPE_REGULAR)
+                GnomeCmdFile *f = (GnomeCmdFile *) files->data;
+                if (f->info->type != GNOME_VFS_FILE_TYPE_REGULAR)
                     return FALSE;
 
                 // Check that the file matches at least one pattern
@@ -296,7 +299,7 @@ inline gboolean fav_app_matches_files (GnomeCmdApp *app, GList *files)
                 for (; patterns; patterns = patterns->next)
                 {
                     gchar *pattern = (gchar *) patterns->data;
-                    ok |= fnmatch (pattern, finfo->info->name, fn_flags) == 0;
+                    ok |= fnmatch (pattern, f->info->name, fn_flags) == 0;
                 }
 
                 if (!ok) return FALSE;
@@ -326,7 +329,7 @@ static void destroy (GtkObject *object)
 {
     GnomeCmdFilePopmenu *menu = GNOME_CMD_FILE_POPMENU (object);
 
-    g_list_foreach (menu->priv->data_list, (GFunc)g_free, NULL);
+    g_list_foreach (menu->priv->data_list, (GFunc) g_free, NULL);
     g_list_free (menu->priv->data_list);
 
     g_free (menu->priv);
@@ -395,9 +398,9 @@ inline gchar *get_default_application_action_name (GList *files)
     if (g_list_length(files)>1)
         return g_strdup(_("_Open"));
 
-    GnomeCmdFile *finfo = (GnomeCmdFile *) files->data;
-    gchar *uri_str = gnome_cmd_file_get_uri_str (finfo);
-    GnomeVFSMimeApplication *app = gnome_vfs_mime_get_default_application_for_uri (uri_str, finfo->info->mime_type);
+    GnomeCmdFile *f = (GnomeCmdFile *) files->data;
+    gchar *uri_str = gnome_cmd_file_get_uri_str (f);
+    GnomeVFSMimeApplication *app = gnome_vfs_mime_get_default_application_for_uri (uri_str, f->info->mime_type);
 
     g_free (uri_str);
 
@@ -460,19 +463,19 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
     };
 
     g_return_val_if_fail (GNOME_CMD_IS_FILE_LIST (fl), NULL);
-    GList *files = gnome_cmd_file_list_get_selected_files (fl);
+    GList *files = fl->get_selected_files();
     if (!files) return NULL;
 
     GnomeCmdFilePopmenu *menu = (GnomeCmdFilePopmenu *) gtk_type_new (gnome_cmd_file_popmenu_get_type ());
 
-    GnomeCmdFile *finfo = (GnomeCmdFile *) files->data;
+    GnomeCmdFile *f = (GnomeCmdFile *) files->data;
 
 
     // Fill the "Open with..." menu with applications
     gint i = -1;
     menu->priv->data_list = NULL;
 
-    vfs_apps = tmp = gnome_vfs_mime_get_all_applications (finfo->info->mime_type);
+    vfs_apps = tmp = gnome_vfs_mime_get_all_applications (f->info->mime_type);
     for (; vfs_apps && i < MAX_OPEN_WITH_APPS; vfs_apps = vfs_apps->next)
     {
         GnomeVFSMimeApplication *vfs_app = (GnomeVFSMimeApplication *) vfs_apps->data;
@@ -525,7 +528,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
     g_free ((gpointer) open_uiinfo[0].label);
 
     pos += 3;
-    if (gnome_cmd_file_is_executable (finfo) && g_list_length (files) == 1)
+    if (gnome_cmd_file_is_executable (f) && g_list_length (files) == 1)
         gnome_app_fill_menu (GTK_MENU_SHELL (menu), exec_uiinfo, NULL, FALSE, pos++);
 
     gnome_app_fill_menu (GTK_MENU_SHELL (menu), sep_uiinfo, NULL, FALSE, pos++);
@@ -602,7 +605,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
 }
 
 
-GtkType gnome_cmd_file_popmenu_get_type (void)
+GtkType gnome_cmd_file_popmenu_get_type ()
 {
     static GtkType dlg_type = 0;
 
