@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-list-popmenu.h"
 #include "gnome-cmd-file-selector.h"
@@ -33,14 +35,10 @@ using namespace std;
 
 static GtkMenuClass *parent_class = NULL;
 
-struct _GnomeCmdListPopmenuPrivate
-{
-};
-
 
 static void on_new_directory (GtkMenuItem *item, GnomeCmdFileSelector *fs)
 {
-    gnome_cmd_file_selector_show_mkdir_dialog (fs);
+    file_mkdir (item);
 }
 
 
@@ -52,7 +50,7 @@ static void on_new_textfile (GtkMenuItem *item, GnomeCmdFileSelector *fs)
 
 static void on_refresh (GtkMenuItem *item, GnomeCmdFileSelector *fs)
 {
-    gnome_cmd_file_selector_reload (fs);
+    fs->reload();
 }
 
 
@@ -68,10 +66,6 @@ static void on_paste (GtkMenuItem *item, GnomeCmdFileSelector *fs)
 
 static void destroy (GtkObject *object)
 {
-    GnomeCmdListPopmenu *menu = GNOME_CMD_LIST_POPMENU (object);
-
-    g_free (menu->priv);
-
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
         (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
@@ -97,7 +91,6 @@ static void class_init (GnomeCmdListPopmenuClass *klass)
 
 static void init (GnomeCmdListPopmenu *menu)
 {
-    menu->priv = g_new0 (GnomeCmdListPopmenuPrivate, 1);
 }
 
 
@@ -149,7 +142,7 @@ GtkWidget *gnome_cmd_list_popmenu_new (GnomeCmdFileSelector *fs)
 }
 
 
-GtkType gnome_cmd_list_popmenu_get_type (void)
+GtkType gnome_cmd_list_popmenu_get_type ()
 {
     static GtkType type = 0;
 
