@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,8 +23,6 @@
 #include "gnome-cmd-file.h"
 #include "plugin_manager.h"
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_MAIN_MENU(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_main_menu_get_type (), GnomeCmdMainMenu)
 #define GNOME_CMD_MAIN_MENU_CLASS(klass) \
@@ -32,43 +31,33 @@ G_BEGIN_DECLS
     GTK_CHECK_TYPE (obj, gnome_cmd_main_menu_get_type ())
 
 
-typedef struct _GnomeCmdMainMenu GnomeCmdMainMenu;
-typedef struct _GnomeCmdMainMenuPrivate GnomeCmdMainMenuPrivate;
-typedef struct _GnomeCmdMainMenuClass GnomeCmdMainMenuClass;
+struct GnomeCmdMainMenuPrivate;
 
 
-
-struct _GnomeCmdMainMenu
+struct GnomeCmdMainMenu
 {
     GtkMenuBar parent;
+
     GnomeCmdMainMenuPrivate *priv;
 };
 
 
-struct _GnomeCmdMainMenuClass
+struct GnomeCmdMainMenuClass
 {
     GtkMenuBarClass parent_class;
 };
 
 
-GtkWidget*
-gnome_cmd_main_menu_new (void);
+GtkWidget *gnome_cmd_main_menu_new ();
 
-GtkType
-gnome_cmd_main_menu_get_type (void);
+GtkType gnome_cmd_main_menu_get_type ();
 
-void
-gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu);
+void gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu);
 
-void
-gnome_cmd_main_menu_update_bookmarks (GnomeCmdMainMenu *main_menu);
+void gnome_cmd_main_menu_update_bookmarks (GnomeCmdMainMenu *main_menu);
 
-void
-gnome_cmd_main_menu_update_sens (GnomeCmdMainMenu *main_menu);
+void gnome_cmd_main_menu_update_sens (GnomeCmdMainMenu *main_menu);
 
-void
-gnome_cmd_main_menu_add_plugin_menu (GnomeCmdMainMenu *main_menu, PluginData *data);
-
-G_END_DECLS
+void gnome_cmd_main_menu_add_plugin_menu (GnomeCmdMainMenu *main_menu, PluginData *data);
 
 #endif // __GNOME_CMD_MAIN_MENU_H__
