@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-path.h"
 
@@ -63,7 +65,7 @@ static void init (GnomeCmdPath *path)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_path_get_type (void)
+GtkType gnome_cmd_path_get_type ()
 {
     static GtkType type = 0;
 
