@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +19,7 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-prepare-xfer-dialog.h"
 #include "gnome-cmd-dir.h"
@@ -37,7 +39,7 @@ static GnomeCmdDialogClass *parent_class = NULL;
 
 inline gboolean con_device_has_path (FileSelectorID fsID, GnomeCmdCon *&dev, const gchar *user_path)
 {
-    dev = gnome_cmd_file_selector_get_connection (gnome_cmd_main_win_get_fs (main_win, fsID));
+    dev = gnome_cmd_main_win_get_fs (main_win, fsID)->get_connection();
 
     return GNOME_CMD_IS_CON_DEVICE (dev) &&
            g_str_has_prefix (user_path, gnome_cmd_con_device_get_mountp (GNOME_CMD_CON_DEVICE (dev)));
@@ -87,7 +89,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
         }
         else
         {
-            gchar *t = gnome_cmd_file_get_path (GNOME_CMD_FILE (gnome_cmd_file_selector_get_directory (dialog->src_fs)));
+            gchar *t = gnome_cmd_file_get_path (GNOME_CMD_FILE (dialog->src_fs->get_directory()));
             dest_path = g_build_path (G_DIR_SEPARATOR_S, t, user_path, NULL);
             g_free (t);
         }
@@ -105,13 +107,13 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
 
     if (g_list_length (dialog->src_files) == 1)
     {
-        GnomeCmdFile *finfo = GNOME_CMD_FILE (dialog->src_files->data);
+        GnomeCmdFile *f = GNOME_CMD_FILE (dialog->src_files->data);
 
         if (res == GNOME_VFS_OK && type == GNOME_VFS_FILE_TYPE_DIRECTORY)
         {
             // There exists a directory, copy into it using the original filename
             dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, dest_path));
-            dest_fn = g_strdup (gnome_cmd_file_get_name (finfo));
+            dest_fn = g_strdup (gnome_cmd_file_get_name (f));
         }
         else
             if (res == GNOME_VFS_OK)
@@ -223,7 +225,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
     gnome_cmd_dir_ref (dest_dir);
     gnome_cmd_xfer_start (dialog->src_files,
                           dest_dir,
-                          dialog->src_fs->list,
+                          dialog->src_fs->file_list(),
                           dest_fn,
                           dialog->xferOptions,
                           dialog->xferOverwriteMode,
@@ -245,10 +247,16 @@ static void on_cancel (GtkButton *button, gpointer user_data)
 
 static gboolean on_dest_dir_entry_keypressed (GtkEntry *entry, GdkEventKey *event, GnomeCmdPrepareXferDialog *dialog)
 {
-    if (event->keyval == GDK_Return)
+    switch (event->keyval)
     {
-        gtk_signal_emit_by_name (GTK_OBJECT (dialog->ok_button), "clicked", dialog, NULL);
-        return TRUE;
+        case GDK_Return:
+            gtk_signal_emit_by_name (GTK_OBJECT (dialog->ok_button), "clicked", dialog, NULL);
+            return TRUE;
+
+        case GDK_F5:
+        case GDK_F6:
+            gnome_cmd_toggle_file_name_selection (dialog->dest_dir_entry);
+            return TRUE;
     }
 
     return FALSE;
@@ -292,8 +300,6 @@ static void class_init (GnomeCmdPrepareXferDialogClass *klass)
 static void init (GnomeCmdPrepareXferDialog *dialog)
 {
     GtkWidget *dest_dir_vbox;
-    GtkWidget *dest_dir_fileentry;
-    GtkWidget *options_hbox;
 
     // dest dir
     dest_dir_vbox = create_vbox (GTK_WIDGET (dialog), FALSE, 0);
@@ -301,16 +307,15 @@ static void init (GnomeCmdPrepareXferDialog *dialog)
     dialog->dest_dir_frame = create_category (GTK_WIDGET (dialog), dest_dir_vbox, "");
     gnome_cmd_dialog_add_category (GNOME_CMD_DIALOG (dialog), dialog->dest_dir_frame);
 
-    dest_dir_fileentry = create_file_entry (GTK_WIDGET (dialog), "file-entry", "");
+    GtkWidget *dest_dir_fileentry = create_file_entry (GTK_WIDGET (dialog), "file-entry", "");
     gtk_box_pack_start (GTK_BOX (dest_dir_vbox), dest_dir_fileentry, FALSE, FALSE, 0);
     dialog->dest_dir_entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (dest_dir_fileentry));
 
     gtk_signal_connect (GTK_OBJECT (dialog->dest_dir_entry), "key-press-event",
                         GTK_SIGNAL_FUNC (on_dest_dir_entry_keypressed), dialog);
 
-
     // options
-    options_hbox = create_hbox (GTK_WIDGET (dialog), TRUE, 6);
+    GtkWidget *options_hbox = create_hbox (GTK_WIDGET (dialog), TRUE, 6);
     gnome_cmd_dialog_add_category (GNOME_CMD_DIALOG (dialog), options_hbox);
 
     dialog->left_vbox = create_vbox (GTK_WIDGET (dialog), FALSE, 0);
@@ -324,8 +329,8 @@ static void init (GnomeCmdPrepareXferDialog *dialog)
 
 
     // buttons
-    dialog->cancel_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_CANCEL, NULL, NULL);
-    dialog->ok_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GNOME_STOCK_BUTTON_OK, NULL, NULL);
+    dialog->cancel_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CANCEL, NULL, NULL);
+    dialog->ok_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK, NULL, NULL);
 
     gtk_signal_connect_after (GTK_OBJECT (dialog->cancel_button), "clicked", GTK_SIGNAL_FUNC (on_cancel), dialog);
     gtk_signal_connect_after (GTK_OBJECT (dialog->ok_button), "clicked", GTK_SIGNAL_FUNC (on_ok), dialog);
@@ -338,7 +343,7 @@ static void init (GnomeCmdPrepareXferDialog *dialog)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_prepare_xfer_dialog_get_type (void)
+GtkType gnome_cmd_prepare_xfer_dialog_get_type ()
 {
     static GtkType dlg_type = 0;
 
@@ -366,8 +371,7 @@ inline gboolean path_points_at_directory (GnomeCmdFileSelector *to, const gchar
 {
     GnomeVFSFileType type;
 
-    GnomeCmdCon *con = gnome_cmd_file_selector_get_connection (to);
-    GnomeVFSResult res = gnome_cmd_con_get_path_target_type (con, dest_path, &type);
+    GnomeVFSResult res = gnome_cmd_con_get_path_target_type (to->get_connection(), dest_path, &type);
 
     return res == GNOME_VFS_OK && type == GNOME_VFS_FILE_TYPE_DIRECTORY;
 }
@@ -381,29 +385,29 @@ GtkWidget *gnome_cmd_prepare_xfer_dialog_new (GnomeCmdFileSelector *from, GnomeC
     gchar *dest_str = NULL;
     GnomeCmdPrepareXferDialog *dialog = (GnomeCmdPrepareXferDialog *) gtk_type_new (gnome_cmd_prepare_xfer_dialog_get_type ());
 
-    dialog->src_files = gnome_cmd_file_list_get_selected_files (from->list);
+    dialog->src_files = from->file_list()->get_selected_files();
     gnome_cmd_file_list_ref (dialog->src_files);
-    dialog->default_dest_dir = gnome_cmd_file_selector_get_directory (to);
+    dialog->default_dest_dir = to->get_directory();
     dialog->src_fs = from;
 
     guint num_files = g_list_length (dialog->src_files);
 
-    if (!gnome_cmd_file_selector_is_local (to))
+    if (!to->is_local())
     {
         if (num_files == 1)
         {
-            GnomeCmdFile *finfo = (GnomeCmdFile *) dialog->src_files->data;
-            dest_str = get_utf8 (finfo->info->name);
+            GnomeCmdFile *f = (GnomeCmdFile *) dialog->src_files->data;
+            dest_str = get_utf8 (f->info->name);
         }
     }
     else
         if (num_files == 1)
         {
-            GnomeCmdFile *finfo = (GnomeCmdFile *) dialog->src_files->data;
+            GnomeCmdFile *f = (GnomeCmdFile *) dialog->src_files->data;
 
             gchar *t = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dialog->default_dest_dir));
             gchar *path = get_utf8 (t);
-            gchar *fname = get_utf8 (finfo->info->name);
+            gchar *fname = get_utf8 (f->info->name);
             g_free (t);
 
             dest_str = g_build_path (G_DIR_SEPARATOR_S, path, fname, NULL);
