@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,11 +18,12 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
+#include <config.h>
 #include <Python.h>
 #include <glib/gprintf.h>
 #include <gdk/gdkx.h>
 #include <dirent.h>
-#include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-file.h"
 #include "gnome-cmd-python-plugin.h"
@@ -150,7 +152,7 @@ void python_plugin_manager_shutdown ()
 {
     for (GList *l=py_plugins; l; l=l->next)
     {
-        PythonPluginData *data = (PythonPluginData *)l->data;
+        PythonPluginData *data = (PythonPluginData *) l->data;
         g_free (data->name);
         g_free (data->path);
         // do not free data->fname, as it points to a part of data->path
@@ -178,7 +180,7 @@ inline gchar *get_dir_as_str (GnomeCmdMainWin *mw, FileSelectorID id)
     if (!fs)
         return NULL;
 
-    GnomeVFSURI *dir_uri = gnome_cmd_dir_get_uri (gnome_cmd_file_selector_get_directory (fs));
+    GnomeVFSURI *dir_uri = gnome_cmd_dir_get_uri (fs->get_directory());
 
     if (!dir_uri)
         return NULL;
@@ -246,7 +248,7 @@ gboolean gnome_cmd_python_plugin_execute(const PythonPluginData *plugin, GnomeCm
     GnomeCmdFileList     *active_fl;
 
     active_fs = gnome_cmd_main_win_get_fs (mw, ACTIVE);
-    active_fl = active_fs ? active_fs->list : NULL;
+    active_fl = active_fs ? active_fs->file_list() : NULL;
 
     if (!GNOME_CMD_IS_FILE_LIST (active_fl))
         goto out_D;
@@ -254,8 +256,8 @@ gboolean gnome_cmd_python_plugin_execute(const PythonPluginData *plugin, GnomeCm
     GList *selected_files;
     GList *f;
 
-    selected_files = gnome_cmd_file_list_get_selected_files (active_fl);
-    f = selected_files = gnome_cmd_file_list_sort_selection (selected_files, active_fl);
+    selected_files = active_fl->get_selected_files();
+    f = selected_files = active_fl->sort_selection(selected_files);
 
     gint n;
 
