@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef __GNOME_CMD_QUICKSEARCH_POPUP_TYPES_H__
 #define __GNOME_CMD_QUICKSEARCH_POPUP_TYPES_H__
@@ -28,12 +29,11 @@
 #define GNOME_CMD_IS_QUICKSEARCH_POPUP(obj) \
     GTK_CHECK_TYPE (obj, gnome_cmd_quicksearch_popup_get_type ())
 
-typedef struct _GnomeCmdQuicksearchPopup GnomeCmdQuicksearchPopup;
-typedef struct _GnomeCmdQuicksearchPopupPrivate GnomeCmdQuicksearchPopupPrivate;
-typedef struct _GnomeCmdQuicksearchPopupClass GnomeCmdQuicksearchPopupClass;
+
+struct GnomeCmdQuicksearchPopupPrivate;
 
 
-struct _GnomeCmdQuicksearchPopup
+struct GnomeCmdQuicksearchPopup
 {
     GtkWindow parent;
 
@@ -47,18 +47,14 @@ struct _GnomeCmdQuicksearchPopup
 };
 
 
-struct _GnomeCmdQuicksearchPopupClass
+struct GnomeCmdQuicksearchPopupClass
 {
     GtkWindowClass parent_class;
 };
 
 
-GtkType
-gnome_cmd_quicksearch_popup_get_type         (void);
+GtkType gnome_cmd_quicksearch_popup_get_type ();
 
-GtkWidget*
-gnome_cmd_quicksearch_popup_new              (GnomeCmdFileList *fl);
+GtkWidget *gnome_cmd_quicksearch_popup_new (GnomeCmdFileList *fl);
 
-
-
-#endif //__GNOME_CMD_QUICKSEARCH_POPUP_TYPES_H__
+#endif // __GNOME_CMD_QUICKSEARCH_POPUP_TYPES_H__
