@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,12 +19,14 @@
 */
 
 #include <config.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-remote-dialog.h"
 #include "gnome-cmd-con-dialog.h"
 #include "gnome-cmd-con-list.h"
 #include "gnome-cmd-con-ftp.h"
 #include "gnome-cmd-data.h"
+#include "gnome-cmd-treeview.h"
 #include "imageloader.h"
 #include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-main-win.h"
@@ -35,7 +38,7 @@ using namespace std;
 static GnomeCmdDialogClass *parent_class = NULL;
 
 
-struct _GnomeCmdRemoteDialogPrivate
+struct GnomeCmdRemoteDialogPrivate
 {
     GtkWidget         *connection_list;
     GtkWidget         *anonymous_pw_entry;
@@ -114,7 +117,7 @@ static gboolean do_connect_real (GnomeCmdConFtp *server)
     GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
     GnomeCmdCon *con = GNOME_CMD_CON (server);
 
-    gnome_cmd_file_selector_set_connection (fs, con);
+    fs->set_connection(con);
     // gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, G_DIR_SEPARATOR_S)));
 
     return FALSE;
@@ -129,16 +132,12 @@ inline void do_connect (GnomeCmdRemoteDialog *ftp_dialog, GnomeCmdConFtp *server
     if (!server)        // exit as there is no server selected
         return;
 
-    const gchar *anon_pw = gtk_entry_get_text (GTK_ENTRY (ftp_dialog->priv->anonymous_pw_entry));
-
     // store the anonymous ftp password as the user might have changed it
+    const gchar *anon_pw = gtk_entry_get_text (GTK_ENTRY (ftp_dialog->priv->anonymous_pw_entry));
     gnome_cmd_data_set_ftp_anonymous_password (anon_pw);
 
     GnomeCmdCon *con = GNOME_CMD_CON (server);
 
-    if (con->method==CON_ANON_FTP)
-        gnome_cmd_con_ftp_set_pw (server, anon_pw);
-
     gtk_widget_destroy (GTK_WIDGET (ftp_dialog));
 
     g_timeout_add (1, (GtkFunction) do_connect_real, server);
@@ -301,16 +300,16 @@ static gint sort_by_auth (GtkTreeModel *model, GtkTreeIter *i1, GtkTreeIter *i2,
 
 static gint sort_by_method (GtkTreeModel *model, GtkTreeIter *i1, GtkTreeIter *i2, gpointer user_data)
 {
-    GnomeCmdConFtp *c1;
-    GnomeCmdConFtp *c2;
+    GnomeCmdCon *c1;
+    GnomeCmdCon *c2;
 
-    gtk_tree_model_get (model, i1, COL_FTP_CON, &c1, -1);
-    gtk_tree_model_get (model, i2, COL_FTP_CON, &c2, -1);
+    gtk_tree_model_get (model, i1, COL_CON, &c1, -1);
+    gtk_tree_model_get (model, i2, COL_CON, &c2, -1);
 
-    if (GNOME_CMD_CON(c1)->method==GNOME_CMD_CON(c2)->method)
+    if (c1->method==c2->method)
         return sort_by_name (model, i1, i2, user_data);
 
-    return int(GNOME_CMD_CON(c1)->method) - int(GNOME_CMD_CON(c2)->method);
+    return int(c1->method) - int(c2->method);
 }
 
 
@@ -344,46 +343,6 @@ inline GtkTreeModel *create_and_fill_model (GList *list)
 }
 
 
-inline GtkTreeViewColumn *create_new_text_column (GtkTreeView *view, GtkCellRenderer *&renderer, gint COL_ID, const gchar *title=NULL)
-{
-    renderer = gtk_cell_renderer_text_new ();
-
-    GtkTreeViewColumn *col = gtk_tree_view_column_new_with_attributes (title,
-                                                                       renderer,
-                                                                       "text", COL_ID,
-                                                                       NULL);
-
-    g_object_set (col,
-                  "clickable", TRUE,
-                  NULL);
-
-    // pack tree view column into tree view
-    gtk_tree_view_append_column (GTK_TREE_VIEW (view), col);
-
-    return col;
-}
-
-
-inline GtkTreeViewColumn *create_new_pixbuf_column (GtkTreeView *view, GtkCellRenderer *&renderer, gint COL_ID, const gchar *title=NULL)
-{
-    renderer = gtk_cell_renderer_pixbuf_new ();
-
-    GtkTreeViewColumn *col = gtk_tree_view_column_new_with_attributes (title,
-                                                                       renderer,
-                                                                       "icon-name", COL_ID,
-                                                                       NULL);
-
-    g_object_set (col,
-                  "clickable", TRUE,
-                  NULL);
-
-    // pack tree view column into tree view
-    gtk_tree_view_append_column (GTK_TREE_VIEW (view), col);
-
-    return col;
-}
-
-
 inline GtkWidget *create_view_and_model (GList *list)
 {
     GtkWidget *view = gtk_tree_view_new ();
@@ -399,24 +358,24 @@ inline GtkWidget *create_view_and_model (GList *list)
 
     GtkTooltips *tips = gtk_tooltips_new ();
 
-    // col = create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_AUTH);
+    // col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_AUTH);
 
-    col = create_new_pixbuf_column (GTK_TREE_VIEW (view), renderer, COL_LOCK);
+    col = gnome_cmd_treeview_create_new_pixbuf_column (GTK_TREE_VIEW (view), renderer, COL_LOCK);
     gtk_tooltips_set_tip (tips, col->button, _("GNOME authentication manager usage"), NULL);
     gtk_tree_view_column_set_sort_column_id (col, SORTID_AUTH);
 
-    col = create_new_pixbuf_column (GTK_TREE_VIEW (view), renderer, COL_METHOD);
+    col = gnome_cmd_treeview_create_new_pixbuf_column (GTK_TREE_VIEW (view), renderer, COL_METHOD);
     gtk_tooltips_set_tip (tips, col->button, _("Network protocol"), NULL);
     gtk_tree_view_column_set_sort_column_id (col, SORTID_METHOD);
 
-    // col = create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_METHOD);
+    // col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_METHOD);
     // gtk_tree_view_column_set_sort_column_id (col, SORTID_METHOD);
     // g_object_set (renderer,
                   // "foreground-set", TRUE,
                   // "foreground", "DarkGray",
                   // NULL);
 
-    col = create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_NAME, _("Name"));
+    col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_NAME, _("Name"));
     gtk_tooltips_set_tip (tips, col->button, _("Connection name"), NULL);
     gtk_tree_view_column_set_sort_column_id (col, SORTID_NAME);
     g_object_set (renderer,
@@ -554,7 +513,7 @@ static void init (GnomeCmdRemoteDialog *ftp_dialog)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_remote_dialog_get_type (void)
+GtkType gnome_cmd_remote_dialog_get_type ()
 {
     static GtkType dlg_type = 0;
 
@@ -578,7 +537,7 @@ GtkType gnome_cmd_remote_dialog_get_type (void)
 }
 
 
-GtkWidget *gnome_cmd_remote_dialog_new (void)
+GtkWidget *gnome_cmd_remote_dialog_new ()
 {
     GnomeCmdRemoteDialog *dialog = (GnomeCmdRemoteDialog *) gtk_type_new (gnome_cmd_remote_dialog_get_type ());
 
@@ -592,9 +551,9 @@ GtkWidget *gnome_cmd_remote_dialog_new (void)
  *
  ***********************************************/
 
-void show_quick_connect_dialog (void)
+void show_quick_connect_dialog ()
 {
-    GnomeCmdConFtp *con = gnome_cmd_data_get_quick_connect ();
+    GnomeCmdConFtp *con = gnome_cmd_data.get_quick_connect();
 
     if (gnome_cmd_connect_dialog_edit (con))
         do_connect_real (con);
