@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,11 +23,11 @@
 #include <regex.h>
 
 #include "gnome-cmd-includes.h"
+#include "gnome-cmd-data.h"
 #include "gnome-cmd-search-dialog.h"
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-file-list.h"
 #include "gnome-cmd-file-selector.h"
-#include "gnome-cmd-data.h"
 #include "gnome-cmd-main-win.h"
 #include "filter.h"
 #include "utils.h"
@@ -39,8 +40,6 @@ static char *msgs[] = {N_("Search _recursively:"),
                        N_("_Unlimited depth"),
                        N_("Current _directory only"),
                        N_("_Limited depth"),
-                       N_("She_ll syntax"),
-                       N_("Rege_x syntax"),
 //                       N_("Search local directories only"),
                        N_("Files _not containing text")};
 #endif
@@ -62,8 +61,8 @@ struct ProtectedData
 
 struct SearchData
 {
-    const gchar *name_pattern;              // the pattern that filenames should match to end up in the file-list
-    const gchar *content_pattern;           // the pattern that the content of a file should match to end up in the file-list
+    const gchar *name_pattern;              // the pattern that file names should match to end up in the file list
+    const gchar *content_pattern;           // the pattern that the content of a file should match to end up in the file list
     const gchar *dir;                       // the current dir of the search routine
 
     Filter *name_filter;
@@ -95,7 +94,7 @@ struct SearchFileData
     guint           len;
 };
 
-struct _GnomeCmdSearchDialogPrivate
+struct GnomeCmdSearchDialogPrivate
 {
     SearchData *data;                       // holds data needed by the search routines
 
@@ -106,7 +105,7 @@ struct _GnomeCmdSearchDialogPrivate
     GtkWidget *dir_entry;
     GtkWidget *find_text_combo;
     GtkWidget *find_text_check;
-    GtkWidget *result_list;
+    GnomeCmdFileList *result_list;
     GtkWidget *statusbar;
 
     GtkWidget *help_button;
@@ -121,13 +120,6 @@ struct _GnomeCmdSearchDialogPrivate
 };
 
 
-static void on_list_file_clicked (GnomeCmdFileList *fl, GnomeCmdFile *finfo, GdkEventButton *button, GnomeCmdSearchDialog *dialog)
-{
-    if (dialog->priv->data->search_done)
-        gtk_widget_set_sensitive (dialog->priv->goto_button, TRUE);
-}
-
-
 /**
  * Puts a string in the statusbar.
  *
@@ -138,9 +130,7 @@ inline void set_statusmsg (SearchData *data, gchar *msg)
         gtk_statusbar_push (GTK_STATUSBAR (data->dialog->priv->statusbar), data->context_id, msg);
 }
 
-/**
- *
- */
+
 inline void search_file_data_free (SearchFileData  *searchfile_data)
 {
     if (searchfile_data->handle != NULL)
@@ -153,19 +143,17 @@ inline void search_file_data_free (SearchFileData  *searchfile_data)
 /**
  * Loads a file in chunks and returns the content.
  */
-static SearchFileData *read_search_file (SearchData      *data,
-                                         SearchFileData  *searchfile_data,
-                                         GnomeCmdFile    *finfo)
+static SearchFileData *read_search_file (SearchData *data, SearchFileData *searchfile_data, GnomeCmdFile *f)
 {
-    g_return_val_if_fail (finfo != NULL, NULL);
-    g_return_val_if_fail (finfo->info != NULL, NULL);
+    g_return_val_if_fail (f != NULL, NULL);
+    g_return_val_if_fail (f->info != NULL, NULL);
 
     GnomeVFSResult  result;
 
     if (searchfile_data == NULL)
     {
         searchfile_data          = g_new0 (SearchFileData, 1);
-        searchfile_data->uri_str = gnome_cmd_file_get_uri_str (finfo);
+        searchfile_data->uri_str = gnome_cmd_file_get_uri_str (f);
         result                   = gnome_vfs_open (&searchfile_data->handle, searchfile_data->uri_str, GNOME_VFS_OPEN_READ);
 
         if (result != GNOME_VFS_OK)
@@ -183,9 +171,9 @@ static SearchFileData *read_search_file (SearchData      *data,
         return NULL;
     }
 
-    if (searchfile_data->len != NULL)
+    if (searchfile_data->len)
     {
-      if ((searchfile_data->offset + searchfile_data->len) >= finfo->info->size)
+      if ((searchfile_data->offset + searchfile_data->len) >= f->info->size)
       {   // end, all has been read
           search_file_data_free (searchfile_data);
           return NULL;
@@ -193,16 +181,16 @@ static SearchFileData *read_search_file (SearchData      *data,
       else
       {   // jump a big step backward to give the regex a chance
           searchfile_data->offset += searchfile_data->len - SEARCH_JUMP_SIZE;
-          if (finfo->info->size < (searchfile_data->offset + (SEARCH_BUFFER_SIZE - 1)))
-              searchfile_data->len = finfo->info->size - searchfile_data->offset;
+          if (f->info->size < (searchfile_data->offset + (SEARCH_BUFFER_SIZE - 1)))
+              searchfile_data->len = f->info->size - searchfile_data->offset;
           else
               searchfile_data->len = SEARCH_BUFFER_SIZE - 1;
       }
     }
     else
     {   // first time call of this function
-        if (finfo->info->size < (SEARCH_BUFFER_SIZE - 1))
-            searchfile_data->len = finfo->info->size;
+        if (f->info->size < (SEARCH_BUFFER_SIZE - 1))
+            searchfile_data->len = f->info->size;
         else
             searchfile_data->len = SEARCH_BUFFER_SIZE - 1;
     }
@@ -232,16 +220,16 @@ static SearchFileData *read_search_file (SearchData      *data,
  * Determines if the content of a file matches an regexp
  *
  */
-inline gboolean content_matches (GnomeCmdFile *finfo, SearchData *data)
+inline gboolean content_matches (GnomeCmdFile *f, SearchData *data)
 {
     gint   ret = REG_NOMATCH;
 
-    if (finfo->info->size > 0)
+    if (f->info->size > 0)
     {
         regmatch_t       match;
         SearchFileData  *search_file = NULL;
 
-        while ((search_file = read_search_file (data, search_file, finfo)) != NULL)
+        while ((search_file = read_search_file (data, search_file, f)) != NULL)
             ret = regexec (data->content_regex, data->search_mem, 1, &match, 0);
     }
 
@@ -254,7 +242,7 @@ inline gboolean content_matches (GnomeCmdFile *finfo, SearchData *data)
  */
 inline gboolean name_matches (gchar *name, SearchData *data)
 {
-    return filter_match (data->name_filter, name);
+    return data->name_filter->match(name);
 }
 
 
@@ -298,17 +286,17 @@ static void search_dir_r (GnomeCmdDir *dir, SearchData *data)
         if (data->stopped)
             return;
 
-        GnomeCmdFile *finfo = (GnomeCmdFile *) tmp->data;
+        GnomeCmdFile *f = (GnomeCmdFile *) tmp->data;
 
         // If the current file is a directory lets continue our recursion
-        if (GNOME_CMD_IS_DIR (finfo) && data->recurse)
+        if (GNOME_CMD_IS_DIR (f) && data->recurse)
         {
             // we don't want to go backwards or follow symlinks
-            if (strcmp (finfo->info->name, ".") != 0 &&
-                strcmp (finfo->info->name, "..") != 0 &&
-                !GNOME_VFS_FILE_INFO_SYMLINK (finfo->info))
+            if (strcmp (f->info->name, ".") != 0 &&
+                strcmp (f->info->name, "..") != 0 &&
+                !GNOME_VFS_FILE_INFO_SYMLINK (f->info))
             {
-                GnomeCmdDir *new_dir = GNOME_CMD_DIR (finfo);
+                GnomeCmdDir *new_dir = GNOME_CMD_DIR (f);
 
                 if (new_dir)
                 {
@@ -320,19 +308,19 @@ static void search_dir_r (GnomeCmdDir *dir, SearchData *data)
         }
         // if the file is a regular one it might match the search criteria
         else
-            if (finfo->info->type == GNOME_VFS_FILE_TYPE_REGULAR)
+            if (f->info->type == GNOME_VFS_FILE_TYPE_REGULAR)
             {
                 // if the name doesn't match lets go to the next file
-                if (!name_matches (finfo->info->name, data))
+                if (!name_matches (f->info->name, data))
                     continue;
 
                 // if the user wants to we should do some content matching here
-                if (data->content_search && !content_matches (finfo, data))
+                if (data->content_search && !content_matches (f, data))
                     continue;
 
                 // the file matched the search criteria, lets add it to the list
                 g_mutex_lock (data->pdata.mutex);
-                data->pdata.files = g_list_append (data->pdata.files, finfo);
+                data->pdata.files = g_list_append (data->pdata.files, f);
                 g_mutex_unlock (data->pdata.mutex);
 
                 // also ref each directory that has a matching file
@@ -354,7 +342,7 @@ static gpointer perform_search_operation (SearchData *data)
     // Unref all directories which contained matching files from last search
     if (data->match_dirs)
     {
-        g_list_foreach (data->match_dirs, (GFunc)gnome_cmd_dir_unref, NULL);
+        g_list_foreach (data->match_dirs, (GFunc) gnome_cmd_dir_unref, NULL);
         g_list_free (data->match_dirs);
         data->match_dirs = NULL;
     }
@@ -362,7 +350,7 @@ static gpointer perform_search_operation (SearchData *data)
     search_dir_r (data->start_dir, data);
 
     // free regexps
-    filter_free (data->name_filter);
+    delete data->name_filter;
     data->name_filter = NULL;
 
     if (data->content_search)
@@ -377,6 +365,8 @@ static gpointer perform_search_operation (SearchData *data)
     data->dir = NULL;
 
     data->search_done = TRUE;
+    gtk_widget_set_sensitive (data->dialog->priv->goto_button, TRUE);
+
     return NULL;
 }
 
@@ -387,8 +377,8 @@ static gboolean update_search_status_widgets (SearchData *data)
 
     // Add all files found since last update to the list
     for (GList *files = data->pdata.files; files; files = files->next)
-        gnome_cmd_file_list_append_file (GNOME_CMD_FILE_LIST (data->dialog->priv->result_list),
-                                      GNOME_CMD_FILE (files->data));
+        data->dialog->priv->result_list->append_file(GNOME_CMD_FILE (files->data));
+
     if (data->pdata.files)
     {
         g_list_free (data->pdata.files);
@@ -429,7 +419,7 @@ static gboolean update_search_status_widgets (SearchData *data)
             gtk_widget_set_sensitive (data->dialog->priv->stop_button, FALSE);
 
             // set focus to result list
-            gtk_widget_grab_focus (data->dialog->priv->result_list);
+            gtk_widget_grab_focus (GTK_WIDGET (data->dialog->priv->result_list));
 
             gtk_widget_hide (data->dialog->priv->pbar);
         }
@@ -471,7 +461,7 @@ static void on_dialog_destroy (GnomeCmdSearchDialog *dialog, gpointer user_data)
     if (data)
     {
         if (!data->search_done)
-            gtk_timeout_remove (data->update_gui_timeout_id);
+            g_source_remove (data->update_gui_timeout_id);
 
         // Stop and wait for search thread to exit
         data->stopped = TRUE;
@@ -496,9 +486,8 @@ static void on_dialog_destroy (GnomeCmdSearchDialog *dialog, gpointer user_data)
 
 static void on_dialog_size_allocate (GtkWidget *widget, GtkAllocation *allocation, GnomeCmdSearchDialog *dialog)
 {
-    SearchDefaults *defaults = gnome_cmd_data_get_search_defaults ();
-    defaults->width  = allocation->width;
-    defaults->height = allocation->height;
+    gnome_cmd_data.search_defaults.width = allocation->width;
+    gnome_cmd_data.search_defaults.height = allocation->height;
 }
 
 
@@ -527,26 +516,27 @@ static gboolean start_search (GnomeCmdSearchDialog *dialog)
     data->case_sens = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->case_check));
 
     // Save default settings
-    SearchDefaults *defaults = gnome_cmd_data_get_search_defaults ();
-
-    defaults->case_sens = data->case_sens;
-    defaults->recursive = data->recurse;
-    defaults->name_patterns = string_history_add (defaults->name_patterns, data->name_pattern, PATTERN_HISTORY_SIZE);
-    defaults->directories = string_history_add (defaults->directories, data->dir, PATTERN_HISTORY_SIZE);
+    gnome_cmd_data.search_defaults.case_sens = data->case_sens;
+    gnome_cmd_data.search_defaults.recursive = data->recurse;
+    gnome_cmd_data.search_defaults.name_patterns.add(data->name_pattern);
+    gnome_cmd_data.search_defaults.directories.add(data->dir);
     if (data->content_search)
-        defaults->content_patterns = string_history_add (defaults->content_patterns, data->content_pattern, PATTERN_HISTORY_SIZE);
+    {
+        gnome_cmd_data.search_defaults.content_patterns.add(data->content_pattern);
+        gnome_cmd_data.intviewer_defaults.text_patterns.add(data->content_pattern);
+    }
 
-    gnome_cmd_file_list_remove_all_files (GNOME_CMD_FILE_LIST (dialog->priv->result_list));
+    dialog->priv->result_list->remove_all_files();
 
     gtk_widget_set_sensitive (data->dialog->priv->search_button, FALSE);
     gtk_widget_set_sensitive (data->dialog->priv->stop_button, TRUE);
 
-    // create an re for filename matching
+    // create an re for file name matching
     GtkWidget *regex_radio = lookup_widget (GTK_WIDGET (dialog), "regex_radio");
 
-    data->name_filter = filter_new (data->name_pattern, data->case_sens,
-                                    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (regex_radio)) ? FILTER_TYPE_REGEX
-                                                                                                   : FILTER_TYPE_FNMATCH);
+    data->name_filter = new Filter(data->name_pattern, data->case_sens,
+                                    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (regex_radio)) ? Filter::TYPE_REGEX
+                                                                                                   : Filter::TYPE_FNMATCH);
 
     // if we're going to search through file content create an re for that too
     if (data->content_search)
@@ -571,7 +561,7 @@ static gboolean start_search (GnomeCmdSearchDialog *dialog)
     data->thread = g_thread_create ((GThreadFunc) perform_search_operation, data, TRUE, NULL);
 
     gtk_widget_show (data->dialog->priv->pbar);
-    data->update_gui_timeout_id = g_timeout_add (gnome_cmd_data_get_gui_update_rate (),
+    data->update_gui_timeout_id = g_timeout_add (gnome_cmd_data.gui_update_rate,
                                                  (GSourceFunc) update_search_status_widgets,
                                                  dialog->priv->data);
     return FALSE;
@@ -627,23 +617,20 @@ static void on_stop (GtkButton *button, GnomeCmdSearchDialog *dialog)
 }
 
 
-/**
- * The user has clicked on the go to button
- *
- */
+//  The user has clicked on the "go to" button
 static void on_goto (GtkButton *button, GnomeCmdSearchDialog *dialog)
 {
-    GnomeCmdFile *finfo = gnome_cmd_file_list_get_selected_file (GNOME_CMD_FILE_LIST (dialog->priv->result_list));
+    GnomeCmdFile *f = dialog->priv->result_list->get_selected_file();
 
-    if (!finfo)
+    if (!f)
         return;
 
-    gchar *fpath = gnome_cmd_file_get_path (finfo);
+    gchar *fpath = gnome_cmd_file_get_path (f);
     gchar *dpath = g_path_get_dirname (fpath);
 
     GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
-    gnome_cmd_file_selector_goto_directory (fs, dpath);
-    gnome_cmd_file_list_focus_file (fs->list, gnome_cmd_file_get_name (finfo), TRUE);
+    fs->goto_directory(dpath);
+    fs->file_list()->focus_file(gnome_cmd_file_get_name (f), TRUE);
 
     g_free (fpath);
     g_free (dpath);
@@ -652,7 +639,7 @@ static void on_goto (GtkButton *button, GnomeCmdSearchDialog *dialog)
 }
 
 
-static gboolean handle_list_keypress (GnomeCmdFileList *fl, GdkEventKey *event, GnomeCmdSearchDialog *dialog)
+inline gboolean handle_list_keypress (GnomeCmdFileList *fl, GdkEventKey *event, GnomeCmdSearchDialog *dialog)
 {
     switch (event->keyval)
     {
@@ -668,12 +655,10 @@ static gboolean handle_list_keypress (GnomeCmdFileList *fl, GdkEventKey *event,
     return FALSE;
 }
 
-/*
- *
- */
+
 static gboolean on_list_keypressed (GtkWidget *result_list,  GdkEventKey *event, gpointer dialog)
 {
-    if (gnome_cmd_file_list_keypressed (GNOME_CMD_FILE_LIST (result_list), event) ||
+    if (GNOME_CMD_FILE_LIST (result_list)->key_pressed(event) ||
         handle_list_keypress (GNOME_CMD_FILE_LIST (result_list), event, GNOME_CMD_SEARCH_DIALOG (dialog)))
     {
         stop_kp (GTK_OBJECT (result_list));
@@ -684,10 +669,7 @@ static gboolean on_list_keypressed (GtkWidget *result_list,  GdkEventKey *event,
 }
 
 
-/**
- * The user has clicked on the "search by content" checkbutton.
- *
- */
+// The user has clicked on the "search by content" checkbutton.
 static void find_text_toggled (GtkToggleButton *togglebutton, GnomeCmdSearchDialog *dialog)
 {
     if (gtk_toggle_button_get_active (togglebutton))
@@ -804,7 +786,7 @@ static void combo_box_insert_text (gpointer  data, gpointer  user_data)
 
 static void init (GnomeCmdSearchDialog *dialog)
 {
-    SearchDefaults *defaults = gnome_cmd_data_get_search_defaults ();
+    GnomeCmdData::SearchConfig &defaults = gnome_cmd_data.search_defaults;
 
     GtkWidget *window;
     GtkWidget *vbox;
@@ -822,7 +804,7 @@ static void init (GnomeCmdSearchDialog *dialog)
     gtk_object_set_data (GTK_OBJECT (window), "window", window);
     gtk_window_set_title (GTK_WINDOW (window), _("Search..."));
     gnome_cmd_dialog_set_resizable (GNOME_CMD_DIALOG (dialog), TRUE);
-    gtk_window_set_default_size (GTK_WINDOW (window), defaults->width, defaults->height);
+    gtk_window_set_default_size (GTK_WINDOW (window), defaults.width, defaults.height);
 
     vbox = create_vbox (window, FALSE, 0);
     gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), vbox);
@@ -838,8 +820,8 @@ static void init (GnomeCmdSearchDialog *dialog)
     table_add (table, label, 0, 0, GTK_FILL);
 
     table_add (table, dialog->priv->pattern_combo, 1, 0, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
-    if (defaults->name_patterns)
-        g_list_foreach (defaults->name_patterns, combo_box_insert_text, dialog->priv->pattern_combo);
+    if (!defaults.name_patterns.empty())
+        g_list_foreach (defaults.name_patterns.ents, combo_box_insert_text, dialog->priv->pattern_combo);
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->pattern_combo), 0);
     gnome_cmd_dialog_editable_enters (GNOME_CMD_DIALOG (dialog), GTK_EDITABLE (gtk_bin_get_child (GTK_BIN (dialog->priv->pattern_combo))));
@@ -850,31 +832,30 @@ static void init (GnomeCmdSearchDialog *dialog)
     table_add (table, label, 0, 1, GTK_FILL);
 
     table_add (table, dialog->priv->dir_browser, 1, 1, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
-    if (defaults->directories)
+    if (!defaults.directories.empty())
         gtk_combo_set_popdown_strings (
             GTK_COMBO (gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (dialog->priv->dir_browser))),
-            defaults->directories);
+            defaults.directories.ents);
 
     dialog->priv->dir_entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (dialog->priv->dir_browser));
 
-
     hbox = create_hbox (window, FALSE, 0);
 
+
     // Recurse check
     dialog->priv->recurse_check = create_check_with_mnemonic (window, _("Search _recursively"), "recurse_check");
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->recurse_check), defaults->recursive);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->recurse_check), defaults.recursive);
+    gtk_box_pack_start (GTK_BOX (hbox), dialog->priv->recurse_check, FALSE, FALSE, 0);
 
 
-    // Filename matching
-    gtk_box_pack_start (GTK_BOX (hbox), dialog->priv->recurse_check, FALSE, TRUE, 0);
-
-    radio = create_radio_with_mnemonic (window, NULL, _("She_ll syntax"), "shell_radio");
-    gtk_container_add (GTK_CONTAINER (hbox), radio);
-    if (gnome_cmd_data_get_filter_type () == FILTER_TYPE_FNMATCH)
+    // File name matching
+    radio = create_radio_with_mnemonic (window, NULL, _("Rege_x syntax"), "regex_radio");
+    gtk_box_pack_end (GTK_BOX (hbox), radio, FALSE, FALSE, 12);
+    if (gnome_cmd_data.filter_type == Filter::TYPE_REGEX)
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
-    radio = create_radio_with_mnemonic (window, get_radio_group (radio), _("Rege_x syntax"), "regex_radio");
-    gtk_container_add (GTK_CONTAINER (hbox), radio);
-    if (gnome_cmd_data_get_filter_type () == FILTER_TYPE_REGEX)
+    radio = create_radio_with_mnemonic (window, get_radio_group (radio), _("She_ll syntax"), "shell_radio");
+    gtk_box_pack_end (GTK_BOX (hbox), radio, FALSE, FALSE, 12);
+    if (gnome_cmd_data.filter_type == Filter::TYPE_FNMATCH)
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
 
     table_add (table, hbox, 1, 2, GTK_FILL);
@@ -887,8 +868,8 @@ static void init (GnomeCmdSearchDialog *dialog)
     dialog->priv->find_text_combo = create_combo_box_entry (window);
     table_add (table, dialog->priv->find_text_combo, 1, 3, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
     gtk_widget_set_sensitive (dialog->priv->find_text_combo, FALSE);
-    if (defaults->content_patterns)
-        g_list_foreach (defaults->content_patterns, combo_box_insert_text, dialog->priv->find_text_combo);
+    if (!defaults.content_patterns.empty())
+        g_list_foreach (defaults.content_patterns.ents, combo_box_insert_text, dialog->priv->find_text_combo);
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->find_text_combo), 0);
     gnome_cmd_dialog_editable_enters (GNOME_CMD_DIALOG (dialog), GTK_EDITABLE (gtk_bin_get_child (GTK_BIN (dialog->priv->find_text_combo))));
@@ -898,7 +879,7 @@ static void init (GnomeCmdSearchDialog *dialog)
     gtk_table_attach (GTK_TABLE (table), dialog->priv->case_check, 1, 2, 4, 5,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->case_check), defaults->case_sens);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->case_check), defaults.case_sens);
 
     dialog->priv->help_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_HELP, GTK_SIGNAL_FUNC (on_help), dialog);
     dialog->priv->close_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_SIGNAL_FUNC (on_close), dialog);
@@ -917,14 +898,12 @@ static void init (GnomeCmdSearchDialog *dialog)
     gtk_box_pack_start (GTK_BOX (vbox), sw, TRUE, TRUE, 0);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-    dialog->priv->result_list = gnome_cmd_file_list_new ();
-    gtk_widget_ref (dialog->priv->result_list);
-    gtk_object_set_data_full (
-        GTK_OBJECT (window), "result_list", dialog->priv->result_list,
-        (GtkDestroyNotify) gtk_widget_unref);
-    gtk_widget_set_size_request (dialog->priv->result_list, -1, 200);
-    gtk_widget_show (dialog->priv->result_list);
-    gtk_container_add (GTK_CONTAINER (sw), dialog->priv->result_list);
+    dialog->priv->result_list = new GnomeCmdFileList;
+    gtk_widget_ref (GTK_WIDGET (dialog->priv->result_list));
+    gtk_object_set_data_full (GTK_OBJECT (window), "result_list", GTK_WIDGET (dialog->priv->result_list), (GtkDestroyNotify) gtk_widget_unref);
+    gtk_widget_set_size_request (GTK_WIDGET (dialog->priv->result_list), -1, 200);
+    gtk_widget_show (GTK_WIDGET (dialog->priv->result_list));
+    gtk_container_add (GTK_CONTAINER (sw), GTK_WIDGET (dialog->priv->result_list));
     gtk_container_set_border_width (GTK_CONTAINER (dialog->priv->result_list), 4);
 
 
@@ -948,14 +927,13 @@ static void init (GnomeCmdSearchDialog *dialog)
     g_signal_connect (G_OBJECT (dialog), "destroy", G_CALLBACK (on_dialog_destroy), NULL);
     g_signal_connect (G_OBJECT (dialog), "size-allocate", G_CALLBACK (on_dialog_size_allocate), NULL);
     g_signal_connect (G_OBJECT (dialog->priv->result_list), "key-press-event", G_CALLBACK (on_list_keypressed), dialog);
-    g_signal_connect (G_OBJECT (dialog->priv->result_list), "file-clicked", G_CALLBACK (on_list_file_clicked), dialog);
 
     gtk_signal_connect (GTK_OBJECT (dialog->priv->find_text_check), "toggled", GTK_SIGNAL_FUNC (find_text_toggled), dialog);
 
     gtk_window_set_keep_above (GTK_WINDOW (dialog), FALSE);
 
     gtk_widget_grab_focus (dialog->priv->pattern_combo);
-    gnome_cmd_file_list_update_style (GNOME_CMD_FILE_LIST (dialog->priv->result_list));
+    dialog->priv->result_list->update_style();
 }
 
 
@@ -963,7 +941,7 @@ static void init (GnomeCmdSearchDialog *dialog)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_search_dialog_get_type (void)
+GtkType gnome_cmd_search_dialog_get_type ()
 {
     static GtkType dlg_type = 0;
 
