@@ -5,6 +5,7 @@
     Part of
         GNOME Commander - A GNOME based file manager
         Copyright (C) 2001-2006 Marcus Bjurman
+        Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +23,6 @@
 */
 
 #include <config.h>
-
 #include <glib.h>
 #include <string.h>
 #include "gvtypes.h"
@@ -31,7 +31,10 @@
 #include "viewer-utils.h"
 #include "cp437.h"
 
-struct _GVInputModesData
+using namespace std;
+
+
+struct GVInputModesData
 {
     gchar *input_mode_name;
 
