@@ -5,6 +5,7 @@
     Part of
         GNOME Commander - A GNOME based file manager
         Copyright (C) 2001-2006 Marcus Bjurman
+        Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +23,6 @@
 */
 
 #include <config.h>
-
 #include <errno.h>
 #include <unistd.h>
 #include <string.h>
@@ -39,7 +39,13 @@
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-file.h"
+#include "gnome-cmd-treeview.h"
 #include "utils.h"
+#include "tags/gnome-cmd-tags.h"
+
+
+using namespace std;
+
 
 #define G_OBJ_CHARSET_KEY        "charset"
 #define G_OBJ_DISPMODE_KEY       "dispmode"
@@ -47,26 +53,13 @@
 #define G_OBJ_IMAGE_OP_KEY       "imageop"
 #define G_OBJ_EXTERNAL_TOOL_KEY  "exttool"
 
-// EXTERNAL TOOLS DISABLED in coming stable release
-#undef EXTERNAL_TOOLS
-
 static GtkWindowClass *parent_class = NULL;
 
-static double image_scale_factors[] = {0.25, 0.5, 0.75, 1, 1.25, 1.50, 2, 2.5, 3, 3.5, 4, 4.5, 5};
+static double image_scale_factors[] = {0.1, 0.2, 0.33, 0.5, 0.67, 1, 1.25, 1.50, 2, 3, 4, 5, 6, 7, 8};
 
 const static int MAX_SCALE_FACTOR_INDEX = G_N_ELEMENTS(image_scale_factors);
 
-#ifdef EXTERNAL_TOOLS
-typedef struct _GViewerWindowExternalTool GViewerWindowExternalTool;
-struct _GViewerWindowExternalTool
-{
-    gchar *name;
-    gchar *command;
-    int   attached_fd;
-};
-#endif
-
-struct _GViewerWindowPrivate
+struct GViewerWindowPrivate
 {
     // Gtk User Interface
     GtkWidget *vbox;
@@ -82,23 +75,16 @@ struct _GViewerWindowPrivate
     GtkWidget *fixed_limit_menu_items[3];
     GViewerWindowSettings state;
 
-    GViewer *exif_viewer;
-    int      exit_data_fd;
-    gboolean exif_active;
-
-    GViewer *active_viewer;
+    GtkWidget *metadata_view;
+    gboolean metadata_visible;
 
     int current_scale_index;
 
+    GnomeCmdFile *f;
     gchar *filename;
     guint statusbar_ctx_id;
     gboolean status_bar_msg;
 
-#ifdef EXTERNAL_TOOLS
-    GHashTable *external_tools;
-    GViewerWindowExternalTool *active_external_tool;
-#endif
-
     GViewerSearcher *srchr;
     gchar *search_pattern;
     gint  search_pattern_len;
@@ -114,23 +100,12 @@ static gboolean gviewer_window_key_pressed(GtkWidget *widget, GdkEventKey *event
 
 static GtkWidget *gviewer_window_create_menus(GViewerWindow *obj);
 
-#ifdef EXTERNAL_TOOLS
-static void gviewer_window_add_external_tool(GViewerWindow *obj, const gchar *name, const gchar *command);
-static void gviewer_window_activate_external_tool(GViewerWindow *obj, const gchar *name);
-static void gviewer_window_activate_internal_viewer(GViewerWindow *obj);
-#endif
-
-static void gviewer_window_show_exif_viewer(GViewerWindow *obj);
-static void gviewer_window_hide_exif_viewer(GViewerWindow *obj);
+inline void gviewer_window_show_metadata(GViewerWindow *obj);
+inline void gviewer_window_hide_metadata(GViewerWindow *obj);
 
 // Event Handlers
 static void menu_file_close (GtkMenuItem *item, GViewerWindow *obj);
 
-#ifdef EXTERNAL_TOOLS
-static void menu_view_external_tool(GtkMenuItem *item, GViewerWindow *obj);
-static void menu_view_internal_viewer(GtkMenuItem *item, GViewerWindow *obj);
-#endif
-
 static void menu_view_exif_information(GtkMenuItem *item, GViewerWindow *obj);
 
 static void menu_edit_copy(GtkMenuItem *item, GViewerWindow *obj);
@@ -155,28 +130,30 @@ static void menu_settings_save_settings(GtkMenuItem *item, GViewerWindow *obj);
 static void menu_help_quick_help(GtkMenuItem *item, GViewerWindow *obj);
 static void menu_help_keyboard(GtkMenuItem *item, GViewerWindow *obj);
 
-static void set_zoom_in(GViewerWindow *obj);
-static void set_zoom_out(GViewerWindow *obj);
-static void set_zoom_normal(GViewerWindow *obj);
 static void set_zoom_best_fit(GViewerWindow *obj);
 
+inline GtkTreeModel *create_model ();
+inline void fill_model (GtkTreeStore *treestore, GnomeCmdFile *f);
+inline GtkWidget *create_view ();
 
 /*****************************************
     public functions
     (defined in the header file)
 *****************************************/
-GtkWidget *gviewer_window_file_view (const gchar * filename, GViewerWindowSettings *initial_settings)
+
+GtkWidget *gviewer_window_file_view (GnomeCmdFile *f, GViewerWindowSettings *initial_settings)
 {
+    GViewerWindowSettings set;
+
     if (!initial_settings)
     {
-        GViewerWindowSettings set;
         gviewer_window_load_settings(&set);
         initial_settings = &set;
     }
 
-    GtkWidget *w = gviewer_window_new(initial_settings);
+    GtkWidget *w = gviewer_window_new ();
 
-    gviewer_window_load_file(GVIEWER_WINDOW(w), filename);
+    gviewer_window_load_file (GVIEWER_WINDOW(w), f);
 
     if (initial_settings)
         gviewer_window_set_settings(GVIEWER_WINDOW(w), initial_settings);
@@ -185,22 +162,22 @@ GtkWidget *gviewer_window_file_view (const gchar * filename, GViewerWindowSettin
 }
 
 
-void gviewer_window_load_file (GViewerWindow *obj, const gchar *filename)
+void gviewer_window_load_file (GViewerWindow *obj, GnomeCmdFile *f)
 {
-    g_return_if_fail (obj);
-    g_return_if_fail (filename);
+    g_return_if_fail(obj!=NULL);
+    g_return_if_fail (f!=NULL);
 
     g_free (obj->priv->filename);
 
-    obj->priv->filename = g_strdup (filename);
+    obj->priv->f = f;
+    obj->priv->filename = gnome_cmd_file_get_real_path (f);
+    gviewer_load_file (obj->priv->viewer, obj->priv->filename);
 
-    gviewer_load_file(obj->priv->viewer, filename);
-
-    gtk_window_set_title(GTK_WINDOW (obj), obj->priv->filename);
+    gtk_window_set_title (GTK_WINDOW(obj), obj->priv->filename);
 }
 
 
-GtkType gviewer_window_get_type (void)
+GtkType gviewer_window_get_type ()
 {
     static GtkType type = 0;
     if (type == 0)
@@ -223,14 +200,6 @@ GtkType gviewer_window_get_type (void)
 }
 
 
-GtkWidget *gviewer_window_new (GViewerWindowSettings *initial_settings)
-{
-    GViewerWindow *w = (GViewerWindow *) gtk_type_new (gviewer_window_get_type ());
-
-    return GTK_WIDGET (w);
-}
-
-
 static void gviewer_window_map (GtkWidget *widget)
 {
     if (GTK_WIDGET_CLASS (parent_class)->map != NULL)
@@ -249,50 +218,21 @@ static void gviewer_window_class_init (GViewerWindowClass *klass)
     widget_class->map = gviewer_window_map;
 }
 
-#ifdef EXTERNAL_TOOLS
-static void gviewer_window_destroy_key(gchar *string)
-{
-    g_free (string);
-}
-
-static void gviewer_window_destroy_external_tool(GViewerWindowExternalTool *tool)
-{
-    if (!tool)
-        return;
-
-    g_free (tool->name);
-    g_free (tool->command);
-    if (tool->attached_fd!=-1)
-        close(tool->attached_fd);
-
-    g_free (tool);
-}
-#endif
-
 
 static void gviewer_window_init (GViewerWindow *w)
 {
     w->priv = g_new0 (GViewerWindowPrivate, 1);
 
-    w->priv->status_bar_msg = FALSE;
-    w->priv->filename = NULL;
-#ifdef EXTERNAL_TOOLS
-    w->priv->active_external_tool = NULL;
-#endif
-    w->priv->exit_data_fd = -1;
-    w->priv->exif_active = FALSE;
-    w->priv->current_scale_index = 3;
-
-#ifdef EXTERNAL_TOOLS
-    w->priv->external_tools = g_hash_table_new_full(g_str_hash, g_str_equal,
-                    (GDestroyNotify)gviewer_window_destroy_key,
-                    (GDestroyNotify)gviewer_window_destroy_external_tool);
-#endif
+    // w->priv->status_bar_msg = FALSE;
+    // w->priv->filename = NULL;
+    // w->priv->metadata_view = NULL;
+    // w->priv->metadata_visible = FALSE;
+    w->priv->current_scale_index = 5;
 
     GtkWindow *win = GTK_WINDOW (w);
     gtk_window_set_title(win, "GViewer");
 
-    g_signal_connect(G_OBJECT (w), "key_press_event", G_CALLBACK (gviewer_window_key_pressed), NULL);
+    g_signal_connect(G_OBJECT (w), "key-press-event", G_CALLBACK (gviewer_window_key_pressed), NULL);
 
     w->priv->vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (w->priv->vbox);
@@ -302,14 +242,11 @@ static void gviewer_window_init (GViewerWindow *w)
     gtk_box_pack_start (GTK_BOX (w->priv->vbox), w->priv->menubar, FALSE, FALSE, 0);
 
     w->priv->viewer = (GViewer *) gviewer_new();
-    g_object_ref(G_OBJECT (w->priv->viewer));
-    gtk_widget_show(GTK_WIDGET (w->priv->viewer));
+    g_object_ref (G_OBJECT (w->priv->viewer));
+    gtk_widget_show (GTK_WIDGET (w->priv->viewer));
     gtk_box_pack_start (GTK_BOX (w->priv->vbox), GTK_WIDGET (w->priv->viewer), TRUE, TRUE, 0);
-    w->priv->exif_viewer = (GViewer *) gviewer_new();
-    g_object_ref(G_OBJECT (w->priv->exif_viewer));
-
-    g_signal_connect(G_OBJECT (w->priv->viewer), "status_line_changed", G_CALLBACK (gviewer_window_status_line_changed), (gpointer) w);
 
+    g_signal_connect(G_OBJECT (w->priv->viewer), "status-line-changed", G_CALLBACK (gviewer_window_status_line_changed), (gpointer) w);
 
     w->priv->statusbar = gtk_statusbar_new ();
     gtk_widget_show (w->priv->statusbar);
@@ -317,16 +254,9 @@ static void gviewer_window_init (GViewerWindow *w)
 
     w->priv->statusbar_ctx_id  = gtk_statusbar_get_context_id(GTK_STATUSBAR(w->priv->statusbar), "info");
 
-    gtk_widget_grab_focus(GTK_WIDGET (w->priv->viewer));
+    gtk_widget_grab_focus (GTK_WIDGET (w->priv->viewer));
 
     gtk_container_add(GTK_CONTAINER (w), w->priv->vbox);
-
-    w->priv->active_viewer = w->priv->viewer;
-
-#ifdef EXTERNAL_TOOLS
-    gviewer_window_add_external_tool(w, "html", "html2text -nobs '%s'");
-    gviewer_window_add_external_tool(w, "pspdf", "ps2ascii '%s'");
-#endif
 }
 
 
@@ -435,20 +365,11 @@ static void gviewer_window_destroy (GtkObject *widget)
 
     if (w->priv)
     {
-        g_object_unref(G_OBJECT (w->priv->viewer));
-        g_object_unref(G_OBJECT (w->priv->exif_viewer));
-
-#ifdef EXTERNAL_TOOLS
-        g_hash_table_destroy(w->priv->external_tools);
-#endif
+        g_object_unref (G_OBJECT (w->priv->viewer));
 
         g_free (w->priv->filename);
         w->priv->filename = NULL;
 
-        if (w->priv->exit_data_fd!=-1)
-            close(w->priv->exit_data_fd);
-        w->priv->exit_data_fd = -1;
-
         g_free (w->priv);
         w->priv = NULL;
     }
@@ -465,16 +386,38 @@ static gboolean gviewer_window_key_pressed(GtkWidget *widget, GdkEventKey *event
 
     GViewerWindow *w = GVIEWER_WINDOW (widget);
 
-    if (event->state & GDK_CONTROL_MASK)
+    switch (event->keyval)
+    {
+        case GDK_plus:
+        case GDK_KP_Add:
+        case GDK_equal:
+           menu_view_zoom_in(NULL, w);
+           return TRUE;
+
+        case GDK_minus:
+        case GDK_KP_Subtract:
+           menu_view_zoom_out(NULL, w);
+           return TRUE;
+    }
+
+    if (state_is_ctrl(event->state))
         switch (event->keyval)
         {
+            case GDK_t:
+            case GDK_T:
+                if (w->priv->metadata_visible)
+                    gviewer_window_hide_metadata(w);
+                else
+                    gviewer_window_show_metadata(w);
+                return TRUE;
+
             case GDK_w:
             case GDK_W:
                 gtk_widget_destroy(GTK_WIDGET (w));
                 return TRUE;
         }
 
-    if (event->state & GDK_SHIFT_MASK)
+    if (state_is_shift(event->state))
         switch (event->keyval)
         {
             case GDK_F7:
@@ -482,18 +425,24 @@ static gboolean gviewer_window_key_pressed(GtkWidget *widget, GdkEventKey *event
                return TRUE;
         }
 
-    switch (event->keyval)
-    {
-        case GDK_plus:
-        case GDK_KP_Add:
-        case GDK_equal:
-           set_zoom_in(w);
-           return TRUE;
+    if (state_is_alt(event->state))
+        switch (event->keyval)
+        {
+            case GDK_Return:
+            case GDK_KP_Enter:
+                gviewer_window_show_metadata(w);
+                return TRUE;
+        }
 
-        case GDK_minus:
-        case GDK_KP_Subtract:
-           set_zoom_out(w);
-           return TRUE;
+    switch (state_is_blank(event->keyval))
+    {
+        case GDK_t:
+        case GDK_T:
+            if (w->priv->metadata_visible)
+                gviewer_window_hide_metadata(w);
+            else
+                gviewer_window_show_metadata(w);
+            return TRUE;
 
         case GDK_F7:
            menu_edit_find(NULL, w);
@@ -750,9 +699,6 @@ static void create_menu_items (GtkWidget *container, GtkAccelGroup *accel, gpoin
 
 
     GtkWidget *encoding_submenu = NULL;
-#ifdef EXTERNAL_TOOLS
-    GSList *text_parser_list = NULL;
-#endif
     MENU_ITEM_DATA text_menu_items[] = {
         {MI_NORMAL, _("_Copy Text Selection"), GDK_C, GDK_CONTROL_MASK, G_CALLBACK (menu_edit_copy),
                 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_COPY,
@@ -770,21 +716,6 @@ static void create_menu_items (GtkWidget *container, GtkAccelGroup *accel, gpoin
                 GNOME_APP_PIXMAP_NONE, NO_PIXMAP_INFO,
                 NO_GOBJ_KEY, NO_GOBJ_VAL,
                 NO_MENU_ITEM, NO_GSLIST},
-#ifdef EXTERNAL_TOOLS
-        {MI_SEPERATOR},
-        {MI_RADIO, _("_No Parsing (original file)"), NO_KEYVAL, NO_MODIFIER, G_CALLBACK (menu_view_internal_viewer),
-                GNOME_APP_PIXMAP_NONE, NO_PIXMAP_INFO,
-                NO_GOBJ_KEY, NO_GOBJ_VAL,
-                NO_MENU_ITEM, &text_parser_list},
-        {MI_RADIO, _("_HTML Parser"), NO_KEYVAL, NO_MODIFIER, G_CALLBACK (menu_view_external_tool),
-                GNOME_APP_PIXMAP_NONE, NO_PIXMAP_INFO,
-                G_OBJ_EXTERNAL_TOOL_KEY, (gpointer) "html",
-                NO_MENU_ITEM, &text_parser_list},
-        {MI_RADIO, _("_PS/PDF Parser"), NO_KEYVAL, NO_MODIFIER, G_CALLBACK (menu_view_external_tool),
-                GNOME_APP_PIXMAP_NONE, NO_PIXMAP_INFO,
-                G_OBJ_EXTERNAL_TOOL_KEY, (gpointer) "pspdf",
-                NO_MENU_ITEM, &text_parser_list},
-#endif
         {MI_SEPERATOR},
         {MI_CHECK, _("_Wrap lines"), GDK_W, NO_MODIFIER, G_CALLBACK (menu_view_wrap),
                 GNOME_APP_PIXMAP_NONE, NO_PIXMAP_INFO,
@@ -799,10 +730,10 @@ static void create_menu_items (GtkWidget *container, GtkAccelGroup *accel, gpoin
     };
 
 #define ENCODING_MENU_ITEM(label, keyval, value) {MI_RADIO, _(label), \
-    keyval, NO_MODIFIER, G_CALLBACK (menu_view_set_charset), \
-    GNOME_APP_PIXMAP_NONE, NO_PIXMAP_INFO, \
-    G_OBJ_CHARSET_KEY, (gpointer *) GUINT_TO_POINTER(value), \
-    NO_MENU_ITEM, &text_encoding_list}
+            keyval, NO_MODIFIER, G_CALLBACK (menu_view_set_charset), \
+            GNOME_APP_PIXMAP_NONE, NO_PIXMAP_INFO, \
+            G_OBJ_CHARSET_KEY, (gpointer *) GUINT_TO_POINTER(value), \
+            NO_MENU_ITEM, &text_encoding_list}
 
     GSList *text_encoding_list = NULL;
     MENU_ITEM_DATA encoding_menu_items[] = {
@@ -832,7 +763,7 @@ static void create_menu_items (GtkWidget *container, GtkAccelGroup *accel, gpoin
     };
 
     MENU_ITEM_DATA image_menu_items[] = {
-        {MI_CHECK, _("_Show EXIF/IPTC Information"), GDK_e, NO_MODIFIER,
+        {MI_CHECK, _("Show Metadata _Tags"), GDK_t, NO_MODIFIER,
                 G_CALLBACK (menu_view_exif_information),
                 GNOME_APP_PIXMAP_NONE, NO_PIXMAP_INFO,
                 NO_GOBJ_KEY, NO_GOBJ_VAL,
@@ -969,32 +900,12 @@ static void menu_view_exif_information(GtkMenuItem *item, GViewerWindow *obj)
         return;
 
     if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM (item)))
-        gviewer_window_show_exif_viewer(obj);
+        gviewer_window_show_metadata(obj);
     else
-        gviewer_window_hide_exif_viewer(obj);
+        gviewer_window_hide_metadata(obj);
 }
 
 
-#ifdef EXTERNAL_TOOLS
-static void menu_view_external_tool(GtkMenuItem *item, GViewerWindow *obj)
-{
-    g_return_if_fail (obj!=NULL);
-    g_return_if_fail (obj->priv->viewer!=NULL);
-
-    char *tool = (char *) g_object_get_data(G_OBJECT (item), G_OBJ_EXTERNAL_TOOL_KEY);
-    g_return_if_fail (tool);
-
-    gviewer_window_activate_external_tool(obj, tool);
-    gtk_widget_draw(GTK_WIDGET (obj->priv->viewer), NULL);
-}
-
-static void menu_view_internal_viewer(GtkMenuItem *item, GViewerWindow *obj)
-{
-    gviewer_window_activate_internal_viewer(obj);
-}
-#endif
-
-
 static void menu_view_display_mode(GtkMenuItem *item, GViewerWindow *obj)
 {
     g_return_if_fail (obj);
@@ -1007,19 +918,16 @@ static void menu_view_display_mode(GtkMenuItem *item, GViewerWindow *obj)
 
     if (dispmode==DISP_MODE_IMAGE)
     {
-#ifdef EXTERNAL_TOOLS
-        gviewer_window_activate_internal_viewer(obj);
-#endif
         if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM (obj->priv->show_exif_menu_item)))
-            gviewer_window_show_exif_viewer(obj);
+            gviewer_window_show_metadata(obj);
         else
-            gviewer_window_hide_exif_viewer(obj);
+            gviewer_window_hide_metadata(obj);
     }
     else
-        gviewer_window_hide_exif_viewer(obj);
+        gviewer_window_hide_metadata(obj);
 
     gviewer_set_display_mode(obj->priv->viewer, dispmode);
-    gtk_widget_grab_focus(GTK_WIDGET (obj->priv->viewer));
+    gtk_widget_grab_focus (GTK_WIDGET (obj->priv->viewer));
 
     gtk_widget_draw(GTK_WIDGET (obj->priv->viewer), NULL);
 }
@@ -1059,25 +967,114 @@ static void menu_image_operation(GtkMenuItem *item, GViewerWindow *obj)
 
 static void menu_view_zoom_in(GtkMenuItem *item, GViewerWindow *obj)
 {
-    set_zoom_in(obj);
+    g_return_if_fail (obj);
+    g_return_if_fail (obj->priv->viewer);
+
+    switch (gviewer_get_display_mode(obj->priv->viewer))
+    {
+        case DISP_MODE_TEXT_FIXED:
+        case DISP_MODE_BINARY:
+        case DISP_MODE_HEXDUMP:
+            {
+               int size = gviewer_get_font_size(obj->priv->viewer);
+
+               if (size==0 || size>32)  return;
+
+               size++;
+               gviewer_set_font_size(obj->priv->viewer, size);
+            }
+            break;
+
+        case DISP_MODE_IMAGE:
+           {
+               gviewer_set_best_fit(obj->priv->viewer, FALSE);
+
+               if (obj->priv->current_scale_index<MAX_SCALE_FACTOR_INDEX-1)
+                  obj->priv->current_scale_index++;
+
+               if (gviewer_get_scale_factor(obj->priv->viewer) == image_scale_factors[obj->priv->current_scale_index])
+                  return;
+
+               gviewer_set_scale_factor(obj->priv->viewer, image_scale_factors[obj->priv->current_scale_index]);
+           }
+           break;
+
+        default:
+            break;
+        }
 }
 
 
 static void menu_view_zoom_out(GtkMenuItem *item, GViewerWindow *obj)
 {
-    set_zoom_out(obj);
+    g_return_if_fail (obj);
+    g_return_if_fail (obj->priv->viewer);
+
+    switch (gviewer_get_display_mode(obj->priv->viewer))
+    {
+        case DISP_MODE_TEXT_FIXED:
+        case DISP_MODE_BINARY:
+        case DISP_MODE_HEXDUMP:
+            {
+               int size = gviewer_get_font_size(obj->priv->viewer);
+
+               if (size==0 || size<4)  return;
+
+               size--;
+               gviewer_set_font_size(obj->priv->viewer, size);
+            }
+            break;
+
+        case DISP_MODE_IMAGE:
+           gviewer_set_best_fit(obj->priv->viewer, FALSE);
+
+           if (obj->priv->current_scale_index>0)
+               obj->priv->current_scale_index--;
+
+           if (gviewer_get_scale_factor(obj->priv->viewer) == image_scale_factors[obj->priv->current_scale_index])
+              return;
+
+           gviewer_set_scale_factor(obj->priv->viewer, image_scale_factors[obj->priv->current_scale_index]);
+           break;
+
+        default:
+            break;
+        }
 }
 
 
 static void menu_view_zoom_normal(GtkMenuItem *item, GViewerWindow *obj)
 {
-    set_zoom_normal(obj);
+    g_return_if_fail (obj);
+    g_return_if_fail (obj->priv->viewer);
+
+    switch (gviewer_get_display_mode (obj->priv->viewer))
+    {
+        case DISP_MODE_TEXT_FIXED:
+        case DISP_MODE_BINARY:
+        case DISP_MODE_HEXDUMP:
+           // needs to completed with resetting to default font size
+           break;
+
+        case DISP_MODE_IMAGE:
+           gviewer_set_best_fit (obj->priv->viewer, FALSE);
+           gviewer_set_scale_factor(obj->priv->viewer, 1);
+           obj->priv->current_scale_index = 5;
+           break;
+
+        default:
+            break;
+    }
 }
 
 
 static void menu_view_zoom_best_fit(GtkMenuItem *item, GViewerWindow *obj)
 {
-    set_zoom_best_fit(obj);
+    g_return_if_fail (obj);
+    g_return_if_fail (obj->priv->viewer);
+
+    if (gviewer_get_display_mode(obj->priv->viewer)==DISP_MODE_IMAGE)
+        gviewer_set_best_fit(obj->priv->viewer, TRUE);
 }
 
 
@@ -1099,9 +1096,9 @@ static void menu_settings_binary_bytes_per_line(GtkMenuItem *item, GViewerWindow
 static void menu_edit_copy(GtkMenuItem *item, GViewerWindow *obj)
 {
     g_return_if_fail (obj);
-    g_return_if_fail (obj->priv->active_viewer);
+    g_return_if_fail (obj->priv->viewer);
 
-    gviewer_copy_selection(obj->priv->active_viewer);
+    gviewer_copy_selection(obj->priv->viewer);
 }
 
 
@@ -1139,7 +1136,6 @@ static void start_find_thread(GViewerWindow *obj, gboolean forward)
 static void menu_edit_find(GtkMenuItem *item, GViewerWindow *obj)
 {
     g_return_if_fail (obj);
-    g_return_if_fail (obj->priv->active_viewer);
 
     // Show the Search Dialog
     GtkWidget *w = gviewer_search_dlg_new (GTK_WINDOW (obj));
@@ -1152,7 +1148,7 @@ static void menu_edit_find(GtkMenuItem *item, GViewerWindow *obj)
     // If a previous search is active, delete it
     if (obj->priv->srchr!=NULL)
     {
-        g_object_unref(obj->priv->srchr);
+        g_object_unref (obj->priv->srchr);
         obj->priv->srchr = NULL;
 
         g_free (obj->priv->search_pattern);
@@ -1206,7 +1202,6 @@ static void menu_edit_find(GtkMenuItem *item, GViewerWindow *obj)
 static void menu_edit_find_next(GtkMenuItem *item, GViewerWindow *obj)
 {
     g_return_if_fail (obj);
-    g_return_if_fail (obj->priv->active_viewer);
 
     if (!obj->priv->srchr)
     {
@@ -1224,7 +1219,6 @@ static void menu_edit_find_next(GtkMenuItem *item, GViewerWindow *obj)
 static void menu_edit_find_prev(GtkMenuItem *item, GViewerWindow *obj)
 {
     g_return_if_fail (obj);
-    g_return_if_fail (obj->priv->active_viewer);
 
     if (!obj->priv->srchr)
         return;
@@ -1242,12 +1236,6 @@ static void menu_view_wrap(GtkMenuItem *item, GViewerWindow *obj)
 
     gviewer_set_wrap_mode(obj->priv->viewer, wrap);
     gtk_widget_draw (GTK_WIDGET (obj->priv->viewer), NULL);
-
-    if (obj->priv->exif_active)
-    {
-        gviewer_set_wrap_mode(obj->priv->exif_viewer, wrap);
-        gtk_widget_draw (GTK_WIDGET (obj->priv->exif_viewer), NULL);
-    }
 }
 
 
@@ -1258,9 +1246,6 @@ static void menu_settings_hex_decimal_offset(GtkMenuItem *item, GViewerWindow *o
 
     gboolean hex = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item));
     gviewer_set_hex_offset_display(obj->priv->viewer, hex);
-
-    if (obj->priv->exif_active)
-        gviewer_set_hex_offset_display(obj->priv->exif_viewer, hex);
 }
 
 
@@ -1334,294 +1319,164 @@ static void menu_help_keyboard(GtkMenuItem *item, GViewerWindow *obj)
     gnome_cmd_help_display ("gnome-commander.xml", "gnome-commander-internal-viewer-keyboard");
 }
 
-#ifdef EXTERNAL_TOOLS
-inline void gviewer_window_add_external_tool(GViewerWindow *obj, const gchar *name, const gchar *command)
+
+inline void gviewer_window_show_metadata(GViewerWindow *w)
 {
-    g_return_if_fail (obj);
-    g_return_if_fail (name);
-    g_return_if_fail (command);
+    g_return_if_fail (w!=NULL);
+    g_return_if_fail (w->priv->f!=NULL);
 
-    GViewerWindowExternalTool *tool = g_new0 (GViewerWindowExternalTool, 1);
-    g_return_if_fail (tool);
+    if (w->priv->metadata_visible)
+        return;
 
-    tool->name = g_strdup (name);
-    tool->command = g_strdup (command);
-    tool->attached_fd = -1;
-
-    g_hash_table_insert(obj->priv->external_tools, g_strdup (name), tool);
-}
-
-inline int gviewer_window_run_external_tool(GViewerWindow *obj, GViewerWindowExternalTool *tool)
-{
-    gchar *cmd_with_filename = NULL;
-    gchar *cmd_with_redir = NULL;
-
-    g_return_val_if_fail (obj!=NULL, -1);
-    g_return_val_if_fail (tool!=NULL, -1);
-    g_return_val_if_fail (tool->command!=NULL, -1);
-    g_return_val_if_fail (obj->priv->filename!=NULL, -1);
-
-    FILE *file = tmpfile();
-    if (!file)
+    if (!w->priv->metadata_view)
     {
-        g_warning("Failed to create temporary file");
-        goto error;
+        GtkWidget *scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
+        gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+        gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow), 10);
+        gtk_container_add (GTK_CONTAINER (scrolledwindow), create_view ());
+        gtk_box_pack_start (GTK_BOX (w->priv->vbox), scrolledwindow, TRUE, TRUE, 0);
+        w->priv->metadata_view = scrolledwindow;
     }
 
-    int fd = fileno(file);
-    if (fd==-1)
+    GtkWidget *view = gtk_bin_get_child (GTK_BIN (w->priv->metadata_view));
+    GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (view));
+
+    if (!model)
     {
-        fclose(file);
-        g_warning("Failed to extract tempfile descriptor");
-        goto error;
+        model = create_model ();
+        fill_model (GTK_TREE_STORE (model), w->priv->f);
+        gtk_tree_view_set_model (GTK_TREE_VIEW (view), model);
+        g_object_unref (model);          // destroy model automatically with view
+        gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (view)), GTK_SELECTION_NONE);
     }
 
-    cmd_with_filename = g_strdup_printf(tool->command, obj->priv->filename);
+    w->priv->metadata_visible = TRUE;
 
-    cmd_with_redir = g_strdup_printf("%s >&%d", cmd_with_filename, fd);
-
-    if (system(cmd_with_redir)==-1)
-    {
-        fd = -1;
-        g_warning("Program execution (%s) failed", cmd_with_redir);
-        goto error;
-    }
-
-error:
-    g_free (cmd_with_filename);
-    g_free (cmd_with_redir);
-
-    return fd;
-}
-#endif
-
-
-inline int gviewer_window_run_exif (GViewerWindow *obj)
-{
-    g_return_val_if_fail (obj!=NULL, -1);
-    g_return_val_if_fail (obj->priv->filename!=NULL, -1);
-
-    int fd = -1;
-    FILE *file = tmpfile();
-
-    if (!file)
-    {
-        g_warning("Failed to create temporary file");
-        return fd;
-    }
-    fd = fileno(file);
-    if (fd==-1)
-    {
-        fclose(file);
-        g_warning("Failed to extract tempfile descriptor");
-        return fd;
-    }
-
-    gchar *cmd_with_redir = g_strdup_printf("iptc '%s' >&%d", obj->priv->filename, fd);
-
-    if (system(cmd_with_redir)==-1)
-        g_warning("IPTC execution (%s) failed", cmd_with_redir);
-
-    g_free (cmd_with_redir);
-
-    cmd_with_redir = g_strdup_printf("exif '%s' >&%d", obj->priv->filename, fd);
-
-    if (system(cmd_with_redir)==-1)
-        g_warning("EXIF execution (%s) failed", cmd_with_redir);
-
-    g_free (cmd_with_redir);
-
-    return fd;
+    gtk_widget_show_all (w->priv->metadata_view);
 }
 
 
-#ifdef EXTERNAL_TOOLS
-static void gviewer_window_activate_external_tool(GViewerWindow *obj, const gchar *name)
+inline void gviewer_window_hide_metadata(GViewerWindow *obj)
 {
     g_return_if_fail (obj!=NULL);
-    g_return_if_fail (name!=NULL);
+    g_return_if_fail (obj->priv->metadata_view!=NULL);
 
-    GViewerWindowExternalTool *tool = g_hash_table_lookup(obj->priv->external_tools, name);
+    if (!obj->priv->metadata_visible)
+        return;
 
-    if (!tool)
+    obj->priv->metadata_visible = FALSE;
+    // gtk_container_remove (GTK_CONTAINER (obj->priv->vbox), obj->priv->metadata_view);
+    gtk_widget_hide_all (obj->priv->metadata_view);
+    gtk_widget_grab_focus (GTK_WIDGET (obj->priv->viewer));
+}
+
+
+enum
+{
+    COL_TAG,
+    COL_TYPE,
+    COL_NAME,
+    COL_VALUE,
+    COL_DESC,
+    NUM_COLS
+} ;
+
+
+inline GtkTreeModel *create_model ()
+{
+    GtkTreeStore *tree = gtk_tree_store_new (NUM_COLS,
+                                             G_TYPE_UINT,
+                                             G_TYPE_STRING,
+                                             G_TYPE_STRING,
+                                             G_TYPE_STRING,
+                                             G_TYPE_STRING);
+    return GTK_TREE_MODEL (tree);
+}
+
+
+inline void fill_model (GtkTreeStore *tree, GnomeCmdFile *f)
+{
+    if (!gcmd_tags_bulk_load (f))
+        return;
+
+    GnomeCmdTagClass prev_tagclass = TAG_NONE_CLASS;
+
+    GtkTreeIter toplevel;
+
+    for (GnomeCmdFileMetadata::METADATA_COLL::const_iterator i=f->metadata->begin(); i!=f->metadata->end(); ++i)
     {
-        g_warning("Could not find external tool \"%s\"", name);
-        return;
-    }
+        const GnomeCmdTag t = i->first;
+        GnomeCmdTagClass curr_tagclass = gcmd_tags_get_class(t);
 
-    if (obj->priv->active_external_tool==tool)
-        return;
+        if (curr_tagclass==TAG_NONE_CLASS)
+            continue;
 
-    if (tool->attached_fd==-1)
-        tool->attached_fd = gviewer_window_run_external_tool(obj, tool);
-    g_return_if_fail (tool->attached_fd!=-1);
-
-    obj->priv->active_external_tool = tool;
-    gviewer_load_filedesc(obj->priv->viewer, tool->attached_fd);
-}
-
-static void gviewer_window_activate_internal_viewer(GViewerWindow *obj)
-{
-    g_return_if_fail (obj!=NULL);
-
-    // internal viewer is already active
-    if (!obj->priv->active_external_tool)
-        return;
-
-    obj->priv->active_external_tool = NULL;
-    gviewer_load_file(obj->priv->viewer, obj->priv->filename);
-}
-#endif
-
-static void gviewer_window_show_exif_viewer(GViewerWindow *obj)
-{
-    g_return_if_fail (obj!=NULL);
-    g_return_if_fail (obj->priv->exif_viewer!=NULL);
-
-    if (obj->priv->exif_active)
-        return;
-
-    if (obj->priv->exit_data_fd==-1)
-        obj->priv->exit_data_fd = gviewer_window_run_exif (obj);
-
-    g_return_if_fail (obj->priv->exit_data_fd!=-1);
-    gviewer_load_filedesc(obj->priv->exif_viewer, obj->priv->exit_data_fd);
-    gtk_widget_show(GTK_WIDGET (obj->priv->exif_viewer));
-
-    obj->priv->exif_active = TRUE;
-    gtk_box_pack_start (GTK_BOX (obj->priv->vbox), GTK_WIDGET (obj->priv->exif_viewer), TRUE, TRUE, 0);
-
-    obj->priv->active_viewer = obj->priv->exif_viewer;
-
-    gtk_widget_grab_focus (GTK_WIDGET (obj->priv->exif_viewer));
-}
-
-
-static void gviewer_window_hide_exif_viewer(GViewerWindow *obj)
-{
-    g_return_if_fail (obj!=NULL);
-    g_return_if_fail (obj->priv->exif_viewer!=NULL);
-
-    if (!obj->priv->exif_active)
-        return;
-
-    obj->priv->exif_active = FALSE;
-    gtk_container_remove(GTK_CONTAINER (obj->priv->vbox), GTK_WIDGET (obj->priv->exif_viewer));
-    gtk_widget_grab_focus(GTK_WIDGET (obj->priv->viewer));
-
-    obj->priv->active_viewer = obj->priv->viewer;
-}
-
-
-static void set_zoom_in(GViewerWindow *obj)
-{
-    g_return_if_fail (obj);
-    g_return_if_fail (obj->priv->viewer);
-
-    switch (gviewer_get_display_mode(obj->priv->viewer))
-    {
-        case DISP_MODE_TEXT_FIXED:
-        case DISP_MODE_BINARY:
-        case DISP_MODE_HEXDUMP:
-            {
-               int size = gviewer_get_font_size(obj->priv->active_viewer);
-
-               if (size==0 || size>32)  return;
-
-               size++;
-               gviewer_set_font_size(obj->priv->active_viewer, size);
-            }
-            break;
-
-        case DISP_MODE_IMAGE:
-           {
-               gviewer_set_best_fit(obj->priv->viewer, FALSE);
-
-               if (obj->priv->current_scale_index<MAX_SCALE_FACTOR_INDEX-1)
-                  obj->priv->current_scale_index++;
-
-               if (gviewer_get_scale_factor(obj->priv->viewer) == image_scale_factors[obj->priv->current_scale_index])
-                  return;
-
-               gviewer_set_scale_factor(obj->priv->viewer, image_scale_factors[obj->priv->current_scale_index]);
-           }
-           break;
-
-        default:
-            break;
+        if (prev_tagclass!=curr_tagclass)
+        {
+            gtk_tree_store_append (tree, &toplevel, NULL);
+            gtk_tree_store_set (tree, &toplevel,
+                                COL_TAG, TAG_NONE,
+                                COL_TYPE, gcmd_tags_get_class_name(t),
+                                -1);
         }
-}
 
+        for (set<std::string>::const_iterator j=i->second.begin(); j!=i->second.end(); ++j)
+        {
+            GtkTreeIter child;
 
-static void set_zoom_out(GViewerWindow *obj)
-{
-    g_return_if_fail (obj);
-    g_return_if_fail (obj->priv->viewer);
-
-    switch (gviewer_get_display_mode(obj->priv->viewer))
-    {
-        case DISP_MODE_TEXT_FIXED:
-        case DISP_MODE_BINARY:
-        case DISP_MODE_HEXDUMP:
-            {
-               int size = gviewer_get_font_size(obj->priv->active_viewer);
-
-               if (size==0 || size<4)  return;
-
-               size--;
-               gviewer_set_font_size(obj->priv->active_viewer, size);
-            }
-            break;
-
-        case DISP_MODE_IMAGE:
-           gviewer_set_best_fit(obj->priv->viewer, FALSE);
-
-           if (obj->priv->current_scale_index>0)
-               obj->priv->current_scale_index--;
-
-           if (gviewer_get_scale_factor(obj->priv->viewer) == image_scale_factors[obj->priv->current_scale_index])
-              return;
-
-           gviewer_set_scale_factor(obj->priv->viewer, image_scale_factors[obj->priv->current_scale_index]);
-           break;
-
-        default:
-            break;
+            gtk_tree_store_append (tree, &child, &toplevel);
+            gtk_tree_store_set (tree, &child,
+                                COL_TAG, t,
+                                COL_NAME, gcmd_tags_get_title(t),
+                                COL_VALUE, j->c_str(),
+                                COL_DESC, gcmd_tags_get_description(t),
+                                -1);
         }
-}
 
-
-static void set_zoom_normal (GViewerWindow *obj)
-{
-    g_return_if_fail (obj);
-    g_return_if_fail (obj->priv->viewer);
-
-    switch (gviewer_get_display_mode (obj->priv->viewer))
-    {
-        case DISP_MODE_TEXT_FIXED:
-        case DISP_MODE_BINARY:
-        case DISP_MODE_HEXDUMP:
-           // needs to completed with resetting to default font size
-           break;
-
-        case DISP_MODE_IMAGE:
-           gviewer_set_best_fit (obj->priv->viewer, FALSE);
-           gviewer_set_scale_factor(obj->priv->viewer, 1);
-           break;
-
-        default:
-            break;
+        prev_tagclass = curr_tagclass;
     }
+
 }
 
 
-static void set_zoom_best_fit (GViewerWindow *obj)
+inline GtkWidget *create_view ()
 {
-    g_return_if_fail (obj);
-    g_return_if_fail (obj->priv->viewer);
+    GtkWidget *view = gtk_tree_view_new ();
 
-    if (gviewer_get_display_mode(obj->priv->viewer)!=DISP_MODE_IMAGE)
-       return;
+    g_object_set (view,
+                  "rules-hint", TRUE,
+                  "enable-search", TRUE,
+                  "search-column", COL_VALUE,
+                  NULL);
 
-    gviewer_set_best_fit(obj->priv->viewer, TRUE);
+    GtkCellRenderer *renderer = NULL;
+    GtkTreeViewColumn *col = NULL;
+
+    GtkTooltips *tips = gtk_tooltips_new ();
+
+    col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_TYPE, _("Type"));
+    gtk_tooltips_set_tip (tips, col->button, _("Metadata namespace"), NULL);
+
+    g_object_set (renderer,
+                  "weight-set", TRUE,
+                  "weight", PANGO_WEIGHT_BOLD,
+                  NULL);
+
+    col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), COL_NAME, _("Name"));
+    gtk_tooltips_set_tip (tips, col->button, _("Tag name"), NULL);
+
+    col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), COL_VALUE, _("Value"));
+    gtk_tooltips_set_tip (tips, col->button, _("Tag value"), NULL);
+
+    col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_DESC, _("Description"));
+    gtk_tooltips_set_tip (tips, col->button, _("Metadata tag description"), NULL);
+
+    g_object_set (renderer,
+                  "foreground-set", TRUE,
+                  "foreground", "DarkGray",
+                  "ellipsize-set", TRUE,
+                  "ellipsize", PANGO_ELLIPSIZE_END,
+                  NULL);
+
+    return view;
 }
