@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,9 +41,10 @@ typedef enum
     TAG_FLAC        = 1 << 11,
     TAG_ID3         = 1 << 12,
     TAG_VORBIS      = 1 << 13,
-    TAG_RPM         = 1 << 14,
+    TAG_PDF         = 1 << 14,
+    TAG_RPM         = 1 << 15,
     TAG_AUDIO       = TAG_APE | TAG_FLAC | TAG_ID3 | TAG_VORBIS,
-    TAG_DOC         = TAG_CHM+1,
+    TAG_DOC         = TAG_CHM | TAG_PDF,
     TAG_IMAGE       = TAG_EXIF | TAG_IPTC | TAG_ICC
 } GnomeCmdTagClass;
 
@@ -205,7 +207,7 @@ typedef enum
     TAG_EXIF_MODEL,                         // image input equipment model
     TAG_EXIF_NEWCFAPATTERN,                 // color filter array (CFA) geometric pattern of the image sensor when a one-chip color area sensor is used. It does not apply to all sensing methods
     TAG_EXIF_NEWSUBFILETYPE,                // general indication of the kind of data contained in this subfile
-    TAG_EXIF_OECF,                          // Opto-Electoric Conversion Function (OECF) specified in ISO 14524
+    TAG_EXIF_OECF,                          // Opto-Electronic Conversion Function (OECF) specified in ISO 14524
     TAG_EXIF_ORIENTATION,                   // orientation of image
     TAG_EXIF_PHOTOMETRICINTERPRETATION,     // pixel composition
     TAG_EXIF_PIXELXDIMENSION,               // Information specific to compressed data. When a compressed file is recorded, the valid width of the meaningful image must be recorded in this tag, whether or not there is padding data or a restart marker. should not exist in an uncompressed file
@@ -450,6 +452,21 @@ typedef enum
     TAG_IPTC_UNO,                           // eternal, globally unique identification for the object, independent of provider and for any media form
     TAG_IPTC_URGENCY,                       // specifies the editorial urgency of content and not necessarily the envelope handling priority
     TAG_IPTC_WRITEREDITOR,                  // name of the person involved in the writing, editing or correcting the object or caption/abstract
+    TAG_PDF_PAGESIZE,                       // page size format
+    TAG_PDF_PAGEWIDTH,                      // page width in mm
+    TAG_PDF_PAGEHEIGHT,                     // page height in mm
+    TAG_PDF_VERSION,                        // the PDF version of the document
+    TAG_PDF_PRODUCER,                       // the application that converted the document to PDF
+    TAG_PDF_EMBEDDEDFILES,                  // number of embedded files in the document
+    TAG_PDF_OPTIMIZED,                      // set to "1" if optimized for network access
+    TAG_PDF_PRINTING,                       // set to "1" if printing is allowed
+    TAG_PDF_HIRESPRINTING,                  // set to "1" if high resolution printing is allowed
+    TAG_PDF_COPYING,                        // set to "1" if copying the contents is allowed
+    TAG_PDF_MODIFYING,                      // set to "1" if modifying the contents is allowed
+    TAG_PDF_DOCASSEMBLY,                    // set to "1" if inserting, rotating, or deleting pages and creating navigation elements is allowed
+    TAG_PDF_COMMENTING,                     // set to "1" if adding or modifying text annotations is allowed
+    TAG_PDF_FORMFILLING,                    // set to "1" if filling of form fields is allowed
+    TAG_PDF_ACCESSIBILITYSUPPORT,           // set to "1" if accessibility support (eg. screen readers) is enabled
     TAG_VORBIS_CONTACT,                     // contact information for the creators or distributors of the track
     TAG_VORBIS_DESCRIPTION,                 // a textual description of the data
     TAG_VORBIS_LICENSE,                     // license information
@@ -466,12 +483,12 @@ typedef enum
 void gcmd_tags_init();
 void gcmd_tags_shutdown();
 
-GnomeCmdFileMetadata *gcmd_tags_bulk_load(GnomeCmdFile *finfo);
+GnomeCmdFileMetadata *gcmd_tags_bulk_load(GnomeCmdFile *f);
 
 const gchar *gcmd_tags_get_name(const GnomeCmdTag tag);
 const GnomeCmdTagClass gcmd_tags_get_class(const GnomeCmdTag tag);
 const gchar *gcmd_tags_get_class_name(const GnomeCmdTag tag);
-const gchar *gcmd_tags_get_value(GnomeCmdFile *finfo, const GnomeCmdTag tag);
+const gchar *gcmd_tags_get_value(GnomeCmdFile *f, const GnomeCmdTag tag);
 const gchar *gcmd_tags_get_title(const GnomeCmdTag tag);
 const gchar *gcmd_tags_get_description(const GnomeCmdTag tag);
 
@@ -483,11 +500,11 @@ GnomeCmdTag gcmd_tags_get_tag_by_name(const gchar *tag_name, const GnomeCmdTagCl
 // gcmd_tags_get_value_by_name() returns metatag value for given tag_name (eg. AlbumArtist) in the specified tag_class (here TAG_AUDIO)
 // if tag_class is omitted, tag_name must contain fully qualified tag name (eg. Audio.AlbumArtist)
 
-inline const gchar *gcmd_tags_get_value_by_name(GnomeCmdFile *finfo, const gchar *tag_name, const GnomeCmdTagClass tag_class=TAG_NONE_CLASS)
+inline const gchar *gcmd_tags_get_value_by_name(GnomeCmdFile *f, const gchar *tag_name, const GnomeCmdTagClass tag_class=TAG_NONE_CLASS)
 {
-    g_return_val_if_fail (finfo != NULL, "");
+    g_return_val_if_fail (f != NULL, "");
 
-    return gcmd_tags_get_value(finfo, gcmd_tags_get_tag_by_name(tag_name, tag_class));
+    return gcmd_tags_get_value(f, gcmd_tags_get_tag_by_name(tag_name, tag_class));
 }
 
 
