@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +22,7 @@
 #include <locale.h>
 #include <errno.h>
 #include <dirent.h>
+#include <fnmatch.h>
 
 #include <set>
 
@@ -33,14 +35,12 @@
 #include "gnome-cmd-con-list.h"
 #include "gnome-cmd-xfer.h"
 
-#include <fnmatch.h>
-
 using namespace std;
 
 
 typedef struct
 {
-    GnomeCmdFile *finfo;
+    GnomeCmdFile *f;
     GtkWidget *dialog;
     gpointer *args;
 } TmpDlData;
@@ -121,7 +121,7 @@ void run_command_indir (const gchar *in_command, const gchar *dir, gboolean term
     {
         gchar *arg;
 
-        if (gnome_cmd_data_get_use_gcmd_block ())
+        if (gnome_cmd_data.use_gcmd_block)
         {
             gchar *s = g_strdup_printf ("%s; %s/bin/gcmd-block", in_command, PREFIX);
             arg = g_shell_quote (s);
@@ -130,7 +130,7 @@ void run_command_indir (const gchar *in_command, const gchar *dir, gboolean term
         else
             arg = g_shell_quote (in_command);
 
-        command = g_strdup_printf (gnome_cmd_data_get_term (), arg);
+        command = g_strdup_printf (gnome_cmd_data.get_term(), arg);
 
         g_free (arg);
     }
@@ -169,7 +169,7 @@ static gboolean delete_event_callback (gpointer data, gpointer user_data)
 {
     g_return_val_if_fail (GTK_IS_DIALOG (data), FALSE);
 
-    gtk_signal_emit_stop_by_name (GTK_OBJECT (data), "delete_event");
+    gtk_signal_emit_stop_by_name (GTK_OBJECT (data), "delete-event");
 
     return TRUE;
 }
@@ -306,7 +306,7 @@ const gchar *name2string (gchar *filename, gchar *buf, guint max)
 
 const gchar *perm2string (GnomeVFSFilePermissions p, gchar *buf, guint max)
 {
-    switch (gnome_cmd_data_get_perm_disp_mode ())
+    switch (gnome_cmd_data.perm_disp_mode)
     {
         case GNOME_CMD_PERM_DISP_MODE_TEXT:
             return perm2textstring (p, buf, max);
@@ -420,12 +420,21 @@ const gchar *size2string (GnomeVFSFileSize size, GnomeCmdSizeDispMode size_disp_
 
 const gchar *time2string (time_t t, const gchar *date_format)
 {
+    // NOTE: date_format is passed in current locale format
+
     static gchar buf[64];
     struct tm lt;
 
     localtime_r (&t, &lt);
     strftime (buf, sizeof(buf), date_format, &lt);
 
+    // convert formatted date from current locale to UTF8
+    gchar *loc_date = g_locale_to_utf8 (buf, -1, NULL, NULL, NULL);
+    if (loc_date)
+        strncpy (buf, loc_date, sizeof(buf)-1);
+
+    g_free (loc_date);
+
     return buf;
 }
 
@@ -465,13 +474,13 @@ static void on_tmp_download_response (GtkWidget *w, gint id, TmpDlData *dldata)
 {
     if (id == GTK_RESPONSE_YES)
     {
-        gchar *path_str = get_temp_download_filepath (gnome_cmd_file_get_name (dldata->finfo));
+        gchar *path_str = get_temp_download_filepath (gnome_cmd_file_get_name (dldata->f));
 
         if (!path_str) return;
 
         dldata->args[1] = (gpointer) path_str;
 
-        GnomeVFSURI *src_uri = gnome_vfs_uri_dup (gnome_cmd_file_get_uri (dldata->finfo));
+        GnomeVFSURI *src_uri = gnome_vfs_uri_dup (gnome_cmd_file_get_uri (dldata->f));
         GnomeCmdPath *path = gnome_cmd_plain_path_new (path_str);
         GnomeCmdCon *con = get_home_con ();
         GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (con, path);
@@ -495,25 +504,25 @@ static void on_tmp_download_response (GtkWidget *w, gint id, TmpDlData *dldata)
 }
 
 
-void mime_exec_single (GnomeCmdFile *finfo)
+void mime_exec_single (GnomeCmdFile *f)
 {
-    g_return_if_fail (finfo != NULL);
-    g_return_if_fail (finfo->info != NULL);
+    g_return_if_fail (f != NULL);
+    g_return_if_fail (f->info != NULL);
 
     gpointer *args;
     GnomeVFSMimeApplication *vfs_app;
     GnomeCmdApp *app;
 
-    if (!finfo->info->mime_type)
+    if (!f->info->mime_type)
         return;
 
     // Check if the file is a binary executable that lacks the executable bit
 
-    if (!gnome_cmd_file_is_executable (finfo))
+    if (!gnome_cmd_file_is_executable (f))
     {
-        if (gnome_cmd_file_has_mime_type (finfo, "application/x-executable") || gnome_cmd_file_has_mime_type (finfo, "application/x-executable-binary"))
+        if (gnome_cmd_file_has_mime_type (f, "application/x-executable") || gnome_cmd_file_has_mime_type (f, "application/x-executable-binary"))
         {
-            gchar *fname = get_utf8 (finfo->info->name);
+            gchar *fname = get_utf8 (f->info->name);
             gchar *msg = g_strdup_printf (_("\"%s\" seems to be a binary executable file but it lacks the executable bit. Do you want to set it and then run the file?"), fname);
             gint ret = run_simple_dialog (GTK_WIDGET (main_win), FALSE, GTK_MESSAGE_QUESTION, msg,
                                           _("Make Executable?"),
@@ -523,7 +532,7 @@ void mime_exec_single (GnomeCmdFile *finfo)
 
             if (ret != 1)  return;  else
             {
-                GnomeVFSResult result = gnome_cmd_file_chmod (finfo, (GnomeVFSFilePermissions) (finfo->info->permissions|GNOME_VFS_PERM_USER_EXEC));
+                GnomeVFSResult result = gnome_cmd_file_chmod (f, (GnomeVFSFilePermissions) (f->info->permissions|GNOME_VFS_PERM_USER_EXEC));
                 if (result != GNOME_VFS_OK)
                     return;
             }
@@ -532,17 +541,17 @@ void mime_exec_single (GnomeCmdFile *finfo)
 
     // If the file is executable but not a binary file, check if the user wants to exec it or open it
 
-    if (gnome_cmd_file_is_executable (finfo))
+    if (gnome_cmd_file_is_executable (f))
     {
-        if (gnome_cmd_file_has_mime_type (finfo, "application/x-executable") || gnome_cmd_file_has_mime_type (finfo, "application/x-executable-binary") )
+        if (gnome_cmd_file_has_mime_type (f, "application/x-executable") || gnome_cmd_file_has_mime_type (f, "application/x-executable-binary") )
         {
-            gnome_cmd_file_execute (finfo);
+            gnome_cmd_file_execute (f);
             return;
         }
         else
-            if (gnome_cmd_file_mime_begins_with (finfo, "text/"))
+            if (gnome_cmd_file_mime_begins_with (f, "text/"))
             {
-                gchar *fname = get_utf8 (finfo->info->name);
+                gchar *fname = get_utf8 (f->info->name);
                 gchar *msg = g_strdup_printf (_("\"%s\" is an executable text file. Do you want to run it, or display its contents?"), fname);
                 gint ret = run_simple_dialog (GTK_WIDGET (main_win), FALSE, GTK_MESSAGE_QUESTION, msg, _("Run or Display"),
                                               -1, _("Cancel"), _("Display"), _("Run"), NULL);
@@ -552,16 +561,16 @@ void mime_exec_single (GnomeCmdFile *finfo)
                 if (ret != 1)
                 {
                     if (ret == 2)
-                        gnome_cmd_file_execute (finfo);
+                        gnome_cmd_file_execute (f);
                     return;
                 }
             }
     }
 
-    vfs_app = gnome_vfs_mime_get_default_application (finfo->info->mime_type);
+    vfs_app = gnome_vfs_mime_get_default_application (f->info->mime_type);
     if (!vfs_app)
     {
-        no_mime_app_found_error (finfo->info->mime_type);
+        no_mime_app_found_error (f->info->mime_type);
         return;
     }
 
@@ -570,19 +579,19 @@ void mime_exec_single (GnomeCmdFile *finfo)
 
     args = g_new0 (gpointer, 3);
 
-    if (gnome_cmd_file_is_local (finfo))
+    if (gnome_cmd_file_is_local (f))
     {
         args[0] = (gpointer) app;
-        args[1] = (gpointer) g_strdup (gnome_cmd_file_get_real_path (finfo));
+        args[1] = (gpointer) g_strdup (gnome_cmd_file_get_real_path (f));
         args[2] = (gpointer) g_path_get_dirname ((gchar *) args[1]);            // set exec dir for local files
         do_mime_exec_single (args);
     }
     else
     {
-        if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data_get_honor_expect_uris())
+        if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data.honor_expect_uris)
         {
             args[0] = (gpointer) app;
-            args[1] = (gpointer) g_strdup (gnome_cmd_file_get_uri_str (finfo));
+            args[1] = (gpointer) g_strdup (gnome_cmd_file_get_uri_str (f));
             // args[2] is NULL here (don't set exec dir for remote files)
             do_mime_exec_single (args);
         }
@@ -594,7 +603,7 @@ void mime_exec_single (GnomeCmdFile *finfo)
             TmpDlData *dldata = g_new0 (TmpDlData, 1);
             args[0] = (gpointer) app;
             // args[2] is NULL here (don't set exec dir for temporarily downloaded files)
-            dldata->finfo = finfo;
+            dldata->f = f;
             dldata->dialog = dialog;
             dldata->args = args;
 
@@ -655,16 +664,16 @@ void mime_exec_multiple (GList *files, GnomeCmdApp *app)
 
     for (; files; files = files->next)
     {
-        GnomeCmdFile *finfo = (GnomeCmdFile *) files->data;
+        GnomeCmdFile *f = (GnomeCmdFile *) files->data;
 
-        if (gnome_vfs_uri_is_local (gnome_cmd_file_get_uri (finfo)))
-            local_files = g_list_append (local_files, g_strdup (gnome_cmd_file_get_real_path (finfo)));
+        if (gnome_vfs_uri_is_local (gnome_cmd_file_get_uri (f)))
+            local_files = g_list_append (local_files, g_strdup (gnome_cmd_file_get_real_path (f)));
         else
         {
             ++no_of_remote_files;
-            if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data_get_honor_expect_uris())
+            if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data.honor_expect_uris)
             {
-                local_files = g_list_append (local_files,  g_strdup (gnome_cmd_file_get_uri_str (finfo)));
+                local_files = g_list_append (local_files,  g_strdup (gnome_cmd_file_get_uri_str (f)));
             }
             else
             {
@@ -679,11 +688,11 @@ void mime_exec_multiple (GList *files, GnomeCmdApp *app)
 
                 if (retid==1)
                 {
-                    gchar *path_str = get_temp_download_filepath (gnome_cmd_file_get_name (finfo));
+                    gchar *path_str = get_temp_download_filepath (gnome_cmd_file_get_name (f));
 
                     if (!path_str) return;
 
-                    GnomeVFSURI *src_uri = gnome_vfs_uri_dup (gnome_cmd_file_get_uri (finfo));
+                    GnomeVFSURI *src_uri = gnome_vfs_uri_dup (gnome_cmd_file_get_uri (f));
                     GnomeCmdPath *path = gnome_cmd_plain_path_new (path_str);
                     GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (get_home_con (), path);
                     gtk_object_destroy (GTK_OBJECT (path));
@@ -755,48 +764,45 @@ GList *strings_to_uris (gchar *data)
 
 GnomeVFSFileSize calc_tree_size (const GnomeVFSURI *dir_uri)
 {
-    GnomeVFSFileSize size = 0;
-    GnomeVFSFileInfoOptions infoOpts = GNOME_VFS_FILE_INFO_DEFAULT;
-    GList *list = NULL;
-    gchar *dir_uri_str;
-    GnomeVFSResult result;
-
     if (!dir_uri)
         return -1;
 
+    gchar *dir_uri_str;
+
     dir_uri_str = gnome_vfs_uri_to_string (dir_uri, GNOME_VFS_URI_HIDE_NONE);
 
     if (!dir_uri_str)
         return -1;
 
-    result = gnome_vfs_directory_list_load (&list, dir_uri_str, infoOpts);
+    GList *list = NULL;
+    GnomeVFSFileSize size = 0;
 
-    if (result != GNOME_VFS_OK)
-        return 0;
+    GnomeVFSResult result = gnome_vfs_directory_list_load (&list, dir_uri_str, GNOME_VFS_FILE_INFO_DEFAULT);
 
-    if (!list)
-        return 0;
-
-    for (GList *tmp = list; tmp; tmp = tmp->next)
+    if (result==GNOME_VFS_OK && list)
     {
-        GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) tmp->data;
-        if (strcmp (info->name, ".") != 0 && strcmp (info->name, "..") != 0)
+        for (GList *tmp = list; tmp; tmp = tmp->next)
         {
-            if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+            GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) tmp->data;
+            if (strcmp (info->name, ".") != 0 && strcmp (info->name, "..") != 0)
             {
-                GnomeVFSURI *new_dir_uri = gnome_vfs_uri_append_file_name (dir_uri, info->name);
-                size += calc_tree_size (new_dir_uri);
-                gnome_vfs_uri_unref (new_dir_uri);
+                if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+                {
+                    GnomeVFSURI *new_dir_uri = gnome_vfs_uri_append_file_name (dir_uri, info->name);
+                    size += calc_tree_size (new_dir_uri);
+                    gnome_vfs_uri_unref (new_dir_uri);
+                }
+                else
+                    size += info->size;
             }
-            else
-                size += info->size;
         }
+
+        for (GList *tmp = list; tmp; tmp = tmp->next)
+            gnome_vfs_file_info_unref ((GnomeVFSFileInfo *) tmp->data);
+
+        g_list_free (list);
     }
 
-    for (GList *tmp = list; tmp; tmp = tmp->next)
-        gnome_vfs_file_info_unref ((GnomeVFSFileInfo *) tmp->data);
-
-    g_list_free (list);
     g_free (dir_uri_str);
 
     return size;
@@ -805,7 +811,7 @@ GnomeVFSFileSize calc_tree_size (const GnomeVFSURI *dir_uri)
 
 GList *string_history_add (GList *in, const gchar *value, guint maxsize)
 {
-    GList *tmp = g_list_find_custom (in, (gchar *) value, (GCompareFunc)strcmp);
+    GList *tmp = g_list_find_custom (in, (gchar *) value, (GCompareFunc) strcmp);
     GList *out;
 
     // if the same value has been given before move it first in the list
@@ -881,7 +887,7 @@ GtkWidget *create_styled_button (const gchar *text)
 {
     GtkWidget *w = text ? gtk_button_new_with_label (text) : gtk_button_new ();
 
-    gtk_button_set_relief (GTK_BUTTON (w), gnome_cmd_data_get_button_relief ());
+    gtk_button_set_relief (GTK_BUTTON (w), gnome_cmd_data.button_relief);
     gtk_widget_ref (w);
     gtk_widget_show (w);
 
@@ -951,26 +957,26 @@ void set_cursor_busy_for_widget (GtkWidget *widget)
 }
 
 
-void set_cursor_busy (void)
+void set_cursor_busy ()
 {
     set_cursor_busy_for_widget (GTK_WIDGET (main_win));
 }
 
 
-void set_cursor_default (void)
+void set_cursor_default ()
 {
     set_cursor_default_for_widget (GTK_WIDGET (main_win));
 }
 
 
-GList *app_get_linked_libs (GnomeCmdFile *finfo)
+GList *app_get_linked_libs (GnomeCmdFile *f)
 {
-    g_return_val_if_fail (GNOME_CMD_IS_FILE (finfo), NULL);
+    g_return_val_if_fail (GNOME_CMD_IS_FILE (f), NULL);
 
     gchar *s;
     gchar tmp[256];
 
-    gchar *arg = g_shell_quote (gnome_cmd_file_get_real_path (finfo));
+    gchar *arg = g_shell_quote (gnome_cmd_file_get_real_path (f));
     gchar *cmd = g_strdup_printf ("ldd %s", arg);
     g_free (arg);
     FILE *fd = popen (cmd, "r");
@@ -994,14 +1000,14 @@ GList *app_get_linked_libs (GnomeCmdFile *finfo)
 }
 
 
-gboolean app_needs_terminal (GnomeCmdFile *finfo)
+gboolean app_needs_terminal (GnomeCmdFile *f)
 {
     gboolean need_term = TRUE;
 
-    if (strcmp (finfo->info->mime_type, "application/x-executable") && strcmp (finfo->info->mime_type, "application/x-executable-binary"))
+    if (strcmp (f->info->mime_type, "application/x-executable") && strcmp (f->info->mime_type, "application/x-executable-binary"))
         return need_term;
 
-    GList *libs = app_get_linked_libs (finfo);
+    GList *libs = app_get_linked_libs (f);
     if  (!libs) return FALSE;
 
     for (GList *tmp = libs; tmp; tmp = tmp->next)
@@ -1046,7 +1052,7 @@ gchar *get_temp_download_filepath (const gchar *fname)
 }
 
 
-void remove_temp_download_dir (void)
+void remove_temp_download_dir ()
 {
     const gchar *tmp_dir = g_get_tmp_dir ();
 
@@ -1195,8 +1201,8 @@ GList *file_list_to_uri_list (GList *files)
 
     for (; files; files = files->next)
     {
-        GnomeCmdFile *finfo = GNOME_CMD_FILE (files->data);
-        GnomeVFSURI *uri = gnome_cmd_file_get_uri (finfo);
+        GnomeCmdFile *f = GNOME_CMD_FILE (files->data);
+        GnomeVFSURI *uri = gnome_cmd_file_get_uri (f);
 
         if (!uri)
             g_warning ("NULL uri!!!");
@@ -1214,8 +1220,8 @@ GList *file_list_to_info_list (GList *files)
 
     for (; files; files = files->next)
     {
-        GnomeCmdFile *finfo = GNOME_CMD_FILE (files->data);
-        infos = g_list_append (infos, finfo->info);
+        GnomeCmdFile *f = GNOME_CMD_FILE (files->data);
+        infos = g_list_append (infos, f->info);
     }
 
     return infos;
@@ -1317,7 +1323,7 @@ void patlist_free (GList *pattern_list)
 {
     g_return_if_fail (pattern_list != NULL);
 
-    g_list_foreach (pattern_list, (GFunc)g_free, NULL);
+    g_list_foreach (pattern_list, (GFunc) g_free, NULL);
     g_list_free (pattern_list);
 }
 
@@ -1336,6 +1342,48 @@ gboolean patlist_matches (GList *pattern_list, const gchar *s)
 }
 
 
+void gnome_cmd_toggle_file_name_selection (GtkWidget *entry)
+{
+    const gchar *text = gtk_entry_get_text (GTK_ENTRY (entry));
+    const char *s = strrchr(text,G_DIR_SEPARATOR);                  // G_DIR_SEPARATOR is ASCII, g_utf8_strrchr() is not needed here
+    glong base = s ? g_utf8_pointer_to_offset (text, ++s) : 0;
+
+    gint beg;
+    gint end;
+
+    if (!gtk_editable_get_selection_bounds (GTK_EDITABLE (entry), &beg, &end))
+    {
+        beg = base;
+        end = -1;
+    }
+    else
+    {
+        glong text_len = g_utf8_strlen (text, -1);
+
+        s = strrchr(text,'.');                                      // '.' is ASCII, g_utf8_strrchr() is not needed here
+        glong ext = s ? g_utf8_pointer_to_offset (text, s) : -1;
+
+        if (beg==0 && end==text_len)
+        {
+            beg = base;
+            end = ext;
+        }
+        else
+        {
+            if (beg!=base)
+                beg = beg>base ? base : 0;
+            else
+                if (end!=ext || end==text_len)
+                    beg = 0;
+
+            end = -1;
+        }
+    }
+
+    gtk_editable_select_region (GTK_EDITABLE (entry), beg, end);
+}
+
+
 int split(const string &s, vector<string> &coll, const char *sep)
 {
   coll.clear();
